@@ -4,7 +4,6 @@ from contextlib import asynccontextmanager
 from typing import AsyncGenerator, List, Optional, Tuple, Union, cast
 
 from vkwave.api.methods._error import (
-    APIError,
     Error,
     ErrorDispatcher,
     UnsuccessAPIRequestException,
@@ -14,14 +13,17 @@ from vkwave.api.token.token import AnyABCToken, Token
 from vkwave.client.abstract import AbstractAPIClient
 from vkwave.client.context import ResultState
 from vkwave.client.types import MethodName
+from vkwave.client import AIOHTTPClient
+from vkwave import __api_version__
+
 
 from .account import Account
+from .app_widgets import AppWidgets
 from .ads import Ads
-from .app import App
 from .apps import Apps
-from .audio import Audio
 from .auth import Auth
 from .board import Board
+from .donut import Donut
 from .database import Database
 from .docs import Docs
 from .execute import Execute
@@ -33,6 +35,7 @@ from .leads import Leads
 from .likes import Likes
 from .market import Market
 from .messages import Messages
+from .money import Money
 from .newsfeed import Newsfeed
 from .notes import Notes
 from .notifications import Notifications
@@ -40,7 +43,6 @@ from .orders import Orders
 from .pages import Pages
 from .photos import Photos
 from .polls import Polls
-from .pretty import Pretty
 from .search import Search
 from .secure import Secure
 from .stats import Stats
@@ -53,6 +55,9 @@ from .utils import Utils
 from .video import Video
 from .wall import Wall
 from .widgets import Widgets
+from .audio import Audio
+from .pretty_cards import PrettyCards
+
 
 TokensInput = Union[List[AnyABCToken], AnyABCToken]
 ClientsInput = Union[List[AbstractAPIClient], AbstractAPIClient]
@@ -99,11 +104,12 @@ class APIOptionsRequestContext:
 
         self.account = Account("account", self)
         self.ads = Ads("ads", self)
-        self.app = App("app", self)
+        self.app_widgets = AppWidgets("appWidgets", self)
         self.apps = Apps("apps", self)
         self.audio = Audio("audio", self)
         self.auth = Auth("auth", self)
         self.board = Board("board", self)
+        self.donut = Donut('donut', self)
         self.database = Database("database", self)
         self.docs = Docs("docs", self)
         self.execute = Execute("execute", self)
@@ -114,6 +120,7 @@ class APIOptionsRequestContext:
         self.leads = Leads("leads", self)
         self.likes = Likes("likes", self)
         self.market = Market("market", self)
+        self.money = Money("money", self)
         self.messages = Messages("messages", self)
         self.newsfeed = Newsfeed("newsfeed", self)
         self.notes = Notes("notes", self)
@@ -122,7 +129,7 @@ class APIOptionsRequestContext:
         self.pages = Pages("pages", self)
         self.photos = Photos("photos", self)
         self.polls = Polls("polls", self)
-        self.pretty = Pretty("pretty", self)
+        self.pretty_cards = PrettyCards("prettyCards", self)
         self.search = Search("search", self)
         self.secure = Secure("secure", self)
         self.stats = Stats("stats", self)
@@ -138,8 +145,10 @@ class APIOptionsRequestContext:
 
     async def handle_error(self, error: Error) -> Optional[dict]:
         dispatcher = self.api_options.error_dispatcher
-        result = await dispatcher.process_error(error, self)
-        return result
+        if "execute_errors" in error:
+            return await dispatcher.process_execute_errors(error, self)
+        else:
+            return await dispatcher.process_error(error, self)
 
     @asynccontextmanager
     async def sync_token(self) -> AsyncGenerator["APIOptionsRequestContext", None]:
@@ -151,7 +160,8 @@ class APIOptionsRequestContext:
         del copied
         del new
 
-    async def api_request(self, method_name: MethodName, params: dict) -> dict:
+    async def api_request(self, method_name: Union[str, MethodName], params: dict) -> dict:
+        method_name = cast(MethodName, method_name)
         client, token = await self.api_options.get_client_and_token()
 
         params = self.api_options.update_pre_request_params(params, token)
@@ -178,7 +188,10 @@ class APIOptionsRequestContext:
         result = data or exc_data
         result = cast(dict, result)
 
-        if "error" in result:
+        if "error" in result or "execute_errors" in result:
+            if "execute_errors" in result:
+                result["request_params"] = params
+                del result["request_params"]["access_token"]
             err_handler_result = await self.handle_error(Error(result))
             if err_handler_result:
                 result = err_handler_result
@@ -190,16 +203,16 @@ class API:
     def __init__(
         self,
         tokens: TokensInput,
-        clients: ClientsInput,
+        clients: Optional[ClientsInput] = None,
         get_token_strategy: Optional[ABCGetTokenStrategy] = None,
         api_version: Optional[str] = None,
         error_dispatcher: Optional[ErrorDispatcher] = None,
     ):
         self.default_api_options = APIOptions(
             tokens,
-            clients,
+            clients or AIOHTTPClient(),
             get_token_strategy or RandomGetTokenStrategy(),
-            api_version or "5.103",
+            api_version or __api_version__,
             error_dispatcher or ErrorDispatcher(),
         )
 
@@ -209,8 +222,19 @@ class API:
     def with_token(self, token: AnyABCToken) -> APIOptionsRequestContext:
         copied = copy.copy(self.default_api_options)
         copied.tokens = [token]
-        new = APIOptionsRequestContext(copied)
-        return new
+        return APIOptionsRequestContext(copied)
 
     def with_options(self, options: APIOptions) -> APIOptionsRequestContext:
         return APIOptionsRequestContext(options)
+
+    def __enter__(self) -> None:
+        raise TypeError("Use async with instead")
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        pass
+
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc_val, exc_tb):
+        await self.default_api_options.get_client().close()
