@@ -1,10 +1,7 @@
 import typing
 
-from vkwave.client.context import ResultState
 from vkwave.client.types import MethodName
 
-from ._error import Error, UnsuccessAPIRequestException
-
 if typing.TYPE_CHECKING:
     from ._abc import APIOptionsRequestContext
 
