@@ -1,13 +1,14 @@
 from vkwave.types.responses import *
-
 from ._category import Category
 from ._utils import get_params
 
 
 class Account(Category):
     async def ban(
-        self, return_raw_response: bool = False, owner_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id:
         :param return_raw_response: - return result at dict
@@ -20,7 +21,7 @@ class Account(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def change_password(
@@ -72,7 +73,9 @@ class Account(Category):
         return result
 
     async def get_app_permissions(
-        self, user_id: int, return_raw_response: bool = False,
+        self,
+        user_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AccountGetAppPermissionsResponse]:
         """
         :param user_id: - User ID whose settings information shall be got. By default: current user.
@@ -112,7 +115,9 @@ class Account(Category):
         return result
 
     async def get_counters(
-        self, return_raw_response: bool = False, filter: typing.Optional[typing.List[str]] = None,
+        self,
+        return_raw_response: bool = False,
+        filter: typing.Optional[typing.List[str]] = None,
     ) -> typing.Union[dict, AccountGetCountersResponse]:
         """
         :param filter: - Counters to be returned.
@@ -130,7 +135,9 @@ class Account(Category):
         return result
 
     async def get_info(
-        self, return_raw_response: bool = False, fields: typing.Optional[typing.List[str]] = None,
+        self,
+        return_raw_response: bool = False,
+        fields: typing.Optional[typing.List[str]] = None,
     ) -> typing.Union[dict, AccountGetInfoResponse]:
         """
         :param fields: - Fields to return. Possible values: *'country' — user country,, *'https_required' — is "HTTPS only" option enabled,, *'own_posts_default' — is "Show my posts only" option is enabled,, *'no_wall_replies' — are wall replies disabled or not,, *'intro' — is intro passed by user or not,, *'lang' — user language. By default: all.
@@ -148,7 +155,8 @@ class Account(Category):
         return result
 
     async def get_profile_info(
-        self, return_raw_response: bool = False,
+        self,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AccountGetProfileInfoResponse]:
         """
         :param return_raw_response: - return result at dict
@@ -165,7 +173,9 @@ class Account(Category):
         return result
 
     async def get_push_settings(
-        self, return_raw_response: bool = False, device_id: typing.Optional[str] = None,
+        self,
+        return_raw_response: bool = False,
+        device_id: typing.Optional[str] = None,
     ) -> typing.Union[dict, AccountGetPushSettingsResponse]:
         """
         :param device_id: - Unique device ID.
@@ -192,7 +202,7 @@ class Account(Category):
         system_version: typing.Optional[str] = None,
         settings: typing.Optional[str] = None,
         sandbox: typing.Optional[bool] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param token: - Device token used to send notifications. (for mpns, the token shall be URL for sending of notifications)
         :param device_model: - String name of device model.
@@ -211,7 +221,7 @@ class Account(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def save_profile_info(
@@ -223,10 +233,10 @@ class Account(Category):
         screen_name: typing.Optional[str] = None,
         cancel_request_id: typing.Optional[int] = None,
         sex: typing.Optional[int] = None,
-        relation: typing.Optional[BaseBoolInt] = None,
+        relation: typing.Optional[int] = None,
         relation_partner_id: typing.Optional[int] = None,
         bdate: typing.Optional[str] = None,
-        bdate_visibility: typing.Optional[BaseBoolInt] = None,
+        bdate_visibility: typing.Optional[int] = None,
         home_town: typing.Optional[str] = None,
         country_id: typing.Optional[int] = None,
         city_id: typing.Optional[int] = None,
@@ -265,7 +275,7 @@ class Account(Category):
         return_raw_response: bool = False,
         name: typing.Optional[str] = None,
         value: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param name: - Setting name.
         :param value: - Setting value.
@@ -279,12 +289,15 @@ class Account(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def set_name_in_menu(
-        self, user_id: int, return_raw_response: bool = False, name: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        user_id: int,
+        return_raw_response: bool = False,
+        name: typing.Optional[str] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param user_id: - User ID.
         :param name: - Application screen name.
@@ -298,12 +311,13 @@ class Account(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def set_offline(
-        self, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param return_raw_response: - return result at dict
         :return:
@@ -315,12 +329,14 @@ class Account(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def set_online(
-        self, return_raw_response: bool = False, voip: typing.Optional[BaseBoolInt] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        return_raw_response: bool = False,
+        voip: typing.Optional[BaseBoolInt] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param voip: - '1' if videocalls are available for current device.
         :param return_raw_response: - return result at dict
@@ -333,7 +349,7 @@ class Account(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def set_push_settings(
@@ -343,7 +359,7 @@ class Account(Category):
         settings: typing.Optional[str] = None,
         key: typing.Optional[str] = None,
         value: typing.Optional[typing.List[str]] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param device_id: - Unique device ID.
         :param settings: - Push settings in a [vk.com/dev/push_settings|special format].
@@ -359,7 +375,7 @@ class Account(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def set_silence_mode(
@@ -367,9 +383,9 @@ class Account(Category):
         return_raw_response: bool = False,
         device_id: typing.Optional[str] = None,
         time: typing.Optional[int] = None,
-        peer_id: typing.Optional[BaseBoolInt] = None,
-        sound: typing.Optional[BaseBoolInt] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        peer_id: typing.Optional[int] = None,
+        sound: typing.Optional[int] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param device_id: - Unique device ID.
         :param time: - Time in seconds for what notifications should be disabled. '-1' to disable forever.
@@ -385,12 +401,14 @@ class Account(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def unban(
-        self, return_raw_response: bool = False, owner_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id:
         :param return_raw_response: - return result at dict
@@ -403,7 +421,7 @@ class Account(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def unregister_device(
@@ -411,7 +429,7 @@ class Account(Category):
         return_raw_response: bool = False,
         device_id: typing.Optional[str] = None,
         sandbox: typing.Optional[bool] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param device_id: - Unique device ID.
         :param sandbox:
@@ -425,5 +443,5 @@ class Account(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
