@@ -1,12 +1,14 @@
 from vkwave.types.responses import *
-
 from ._category import Category
 from ._utils import get_params
 
 
 class Ads(Category):
     async def add_office_users(
-        self, account_id: int, data: str, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        data: typing.List[AdsUserSpecificationCutted],
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsAddOfficeUsersResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -51,7 +53,10 @@ class Ads(Category):
         return result
 
     async def create_ads(
-        self, account_id: int, data: str, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        data: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsCreateAdsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -70,7 +75,10 @@ class Ads(Category):
         return result
 
     async def create_campaigns(
-        self, account_id: int, data: str, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        data: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsCreateCampaignsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -89,7 +97,10 @@ class Ads(Category):
         return result
 
     async def create_clients(
-        self, account_id: int, data: str, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        data: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsCreateClientsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -111,9 +122,9 @@ class Ads(Category):
         self,
         account_id: int,
         name: str,
+        lifetime: int,
         return_raw_response: bool = False,
         client_id: typing.Optional[int] = None,
-        lifetime: typing.Optional[int] = None,
         target_pixel_id: typing.Optional[int] = None,
         target_pixel_rules: typing.Optional[str] = None,
     ) -> typing.Union[dict, AdsCreateTargetGroupResponse]:
@@ -138,7 +149,10 @@ class Ads(Category):
         return result
 
     async def delete_ads(
-        self, account_id: int, ids: str, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        ids: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsDeleteAdsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -157,7 +171,10 @@ class Ads(Category):
         return result
 
     async def delete_campaigns(
-        self, account_id: int, ids: str, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        ids: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsDeleteCampaignsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -176,7 +193,10 @@ class Ads(Category):
         return result
 
     async def delete_clients(
-        self, account_id: int, ids: str, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        ids: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsDeleteClientsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -200,7 +220,7 @@ class Ads(Category):
         target_group_id: int,
         return_raw_response: bool = False,
         client_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param account_id: - Advertising account ID.
         :param client_id: - 'Only for advertising agencies.' , ID of the client with the advertising account where the group will be created.
@@ -215,11 +235,12 @@ class Ads(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def get_accounts(
-        self, return_raw_response: bool = False,
+        self,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsGetAccountsResponse]:
         """
         :param return_raw_response: - return result at dict
@@ -243,6 +264,7 @@ class Ads(Category):
         campaign_ids: typing.Optional[str] = None,
         client_id: typing.Optional[int] = None,
         include_deleted: typing.Optional[BaseBoolInt] = None,
+        only_deleted: typing.Optional[BaseBoolInt] = None,
         limit: typing.Optional[int] = None,
         offset: typing.Optional[int] = None,
     ) -> typing.Union[dict, AdsGetAdsResponse]:
@@ -252,6 +274,7 @@ class Ads(Category):
         :param campaign_ids: - Filter by advertising campaigns. Serialized JSON array with campaign IDs. If the parameter is null, ads of all campaigns will be shown.
         :param client_id: - 'Available and required for advertising agencies.' ID of the client ads are retrieved from.
         :param include_deleted: - Flag that specifies whether archived ads shall be shown: *0 — show only active ads,, *1 — show all ads.
+        :param only_deleted: - Flag that specifies whether to show only archived ads: *0 — show all ads,, *1 — show only archived ads. Available when include_deleted flag is *1
         :param limit: - Limit of number of returned ads. Used only if ad_ids parameter is null, and 'campaign_ids' parameter contains ID of only one campaign.
         :param offset: - Offset. Used in the same cases as 'limit' parameter.
         :param return_raw_response: - return result at dict
@@ -332,7 +355,9 @@ class Ads(Category):
         return result
 
     async def get_budget(
-        self, account_id: int, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsGetBudgetResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -356,12 +381,14 @@ class Ads(Category):
         client_id: typing.Optional[int] = None,
         include_deleted: typing.Optional[BaseBoolInt] = None,
         campaign_ids: typing.Optional[str] = None,
+        fields: typing.Optional[typing.List[str]] = None,
     ) -> typing.Union[dict, AdsGetCampaignsResponse]:
         """
         :param account_id: - Advertising account ID.
         :param client_id: - 'For advertising agencies'. ID of the client advertising campaigns are retrieved from.
         :param include_deleted: - Flag that specifies whether archived ads shall be shown. *0 — show only active campaigns,, *1 — show all campaigns.
         :param campaign_ids: - Filter of advertising campaigns to show. Serialized JSON array with campaign IDs. Only campaigns that exist in 'campaign_ids' and belong to the specified advertising account will be shown. If the parameter is null, all campaigns will be shown.
+        :param fields:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -376,7 +403,9 @@ class Ads(Category):
         return result
 
     async def get_categories(
-        self, return_raw_response: bool = False, lang: typing.Optional[str] = None,
+        self,
+        return_raw_response: bool = False,
+        lang: typing.Optional[str] = None,
     ) -> typing.Union[dict, AdsGetCategoriesResponse]:
         """
         :param lang: - Language. The full list of supported languages is [vk.com/dev/api_requests|here].
@@ -394,7 +423,9 @@ class Ads(Category):
         return result
 
     async def get_clients(
-        self, account_id: int, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsGetClientsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -415,10 +446,10 @@ class Ads(Category):
         self,
         account_id: int,
         ids_type: str,
-        ids: BaseBoolInt,
+        ids: str,
         period: str,
-        date_from: BaseBoolInt,
-        date_to: BaseBoolInt,
+        date_from: str,
+        date_to: str,
         return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsGetDemographicsResponse]:
         """
@@ -442,7 +473,9 @@ class Ads(Category):
         return result
 
     async def get_flood_stats(
-        self, account_id: int, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsGetFloodStatsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -459,8 +492,60 @@ class Ads(Category):
         result = AdsGetFloodStatsResponse(**raw_result)
         return result
 
+    async def get_lookalike_requests(
+        self,
+        account_id: int,
+        return_raw_response: bool = False,
+        client_id: typing.Optional[int] = None,
+        requests_ids: typing.Optional[str] = None,
+        offset: typing.Optional[int] = None,
+        limit: typing.Optional[int] = None,
+        sort_by: typing.Optional[str] = None,
+    ) -> typing.Union[dict, AdsGetLookalikeRequestsResponse]:
+        """
+        :param account_id:
+        :param client_id:
+        :param requests_ids:
+        :param offset:
+        :param limit:
+        :param sort_by:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("getLookalikeRequests", params)
+        if return_raw_response:
+            return raw_result
+
+        result = AdsGetLookalikeRequestsResponse(**raw_result)
+        return result
+
+    async def get_musicians(
+        self,
+        artist_name: str,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, AdsGetMusiciansResponse]:
+        """
+        :param artist_name:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("getMusicians", params)
+        if return_raw_response:
+            return raw_result
+
+        result = AdsGetMusiciansResponse(**raw_result)
+        return result
+
     async def get_office_users(
-        self, account_id: int, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsGetOfficeUsersResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -478,7 +563,11 @@ class Ads(Category):
         return result
 
     async def get_posts_reach(
-        self, account_id: int, ids_type: str, ids: BaseBoolInt, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        ids_type: str,
+        ids: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsGetPostsReachResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -498,7 +587,10 @@ class Ads(Category):
         return result
 
     async def get_rejection_reason(
-        self, account_id: int, ad_id: int, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        ad_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsGetRejectionReasonResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -520,11 +612,12 @@ class Ads(Category):
         self,
         account_id: int,
         ids_type: str,
-        ids: BaseBoolInt,
+        ids: str,
         period: str,
-        date_from: BaseBoolInt,
-        date_to: BaseBoolInt,
+        date_from: str,
+        date_to: str,
         return_raw_response: bool = False,
+        stats_fields: typing.Optional[typing.List[str]] = None,
     ) -> typing.Union[dict, AdsGetStatisticsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -533,6 +626,7 @@ class Ads(Category):
         :param period: - Data grouping by dates: *day — statistics by days,, *month — statistics by months,, *overall — overall statistics. 'date_from' and 'date_to' parameters set temporary limits.
         :param date_from: - Date to show statistics from. For different value of 'period' different date format is used: *day: YYYY-MM-DD, example: 2011-09-27 — September 27, 2011, **0 — day it was created on,, *month: YYYY-MM, example: 2011-09 — September 2011, **0 — month it was created in,, *overall: 0.
         :param date_to: - Date to show statistics to. For different value of 'period' different date format is used: *day: YYYY-MM-DD, example: 2011-09-27 — September 27, 2011, **0 — current day,, *month: YYYY-MM, example: 2011-09 — September 2011, **0 — current month,, *overall: 0.
+        :param stats_fields: - Additional fields to add to statistics
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -608,11 +702,13 @@ class Ads(Category):
         client_id: typing.Optional[int] = None,
         criteria: typing.Optional[str] = None,
         ad_id: typing.Optional[int] = None,
-        ad_format: typing.Optional[BaseBoolInt] = None,
-        ad_platform: typing.Optional[BaseBoolInt] = None,
+        ad_format: typing.Optional[int] = None,
+        ad_platform: typing.Optional[str] = None,
         ad_platform_no_wall: typing.Optional[str] = None,
         ad_platform_no_ad_network: typing.Optional[str] = None,
         link_domain: typing.Optional[str] = None,
+        need_precise: typing.Optional[BaseBoolInt] = None,
+        impressions_limit_period: typing.Optional[int] = None,
     ) -> typing.Union[dict, AdsGetTargetingStatsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -625,6 +721,8 @@ class Ads(Category):
         :param ad_platform_no_ad_network:
         :param link_url: - URL for the advertised object.
         :param link_domain: - Domain of the advertised object.
+        :param need_precise: - Additionally return recommended cpc and cpm to reach 5,10..95 percents of audience.
+        :param impressions_limit_period: - Impressions limit period in seconds, must be a multiple of 86400(day)
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -639,7 +737,10 @@ class Ads(Category):
         return result
 
     async def get_upload_u_r_l(
-        self, ad_format: int, return_raw_response: bool = False, icon: typing.Optional[int] = None,
+        self,
+        ad_format: int,
+        return_raw_response: bool = False,
+        icon: typing.Optional[int] = None,
     ) -> typing.Union[dict, AdsGetUploadURLResponse]:
         """
         :param ad_format: - Ad format: *1 — image and text,, *2 — big image,, *3 — exclusive format,, *4 — community, square image,, *7 — special app format.
@@ -658,7 +759,8 @@ class Ads(Category):
         return result
 
     async def get_video_upload_u_r_l(
-        self, return_raw_response: bool = False,
+        self,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsGetVideoUploadURLResponse]:
         """
         :param return_raw_response: - return result at dict
@@ -701,7 +803,10 @@ class Ads(Category):
         return result
 
     async def remove_office_users(
-        self, account_id: int, ids: str, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        ids: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsRemoveOfficeUsersResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -720,7 +825,10 @@ class Ads(Category):
         return result
 
     async def update_ads(
-        self, account_id: int, data: str, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        data: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsUpdateAdsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -739,7 +847,10 @@ class Ads(Category):
         return result
 
     async def update_campaigns(
-        self, account_id: int, data: str, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        data: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsUpdateCampaignsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -758,7 +869,10 @@ class Ads(Category):
         return result
 
     async def update_clients(
-        self, account_id: int, data: str, return_raw_response: bool = False,
+        self,
+        account_id: int,
+        data: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AdsUpdateClientsResponse]:
         """
         :param account_id: - Advertising account ID.
@@ -776,25 +890,47 @@ class Ads(Category):
         result = AdsUpdateClientsResponse(**raw_result)
         return result
 
+    async def update_office_users(
+        self,
+        account_id: int,
+        data: typing.List[AdsUserSpecification],
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, AdsUpdateOfficeUsersResponse]:
+        """
+        :param account_id: - Advertising account ID.
+        :param data: - Serialized JSON array of objects that describe added managers. Description of 'user_specification' objects see below.
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("updateOfficeUsers", params)
+        if return_raw_response:
+            return raw_result
+
+        result = AdsUpdateOfficeUsersResponse(**raw_result)
+        return result
+
     async def update_target_group(
         self,
         account_id: int,
         target_group_id: int,
         name: str,
+        lifetime: int,
         return_raw_response: bool = False,
         client_id: typing.Optional[int] = None,
         domain: typing.Optional[str] = None,
-        lifetime: typing.Optional[BaseBoolInt] = None,
         target_pixel_id: typing.Optional[int] = None,
         target_pixel_rules: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param account_id: - Advertising account ID.
         :param client_id: - 'Only for advertising agencies.' , ID of the client with the advertising account where the group will be created.
         :param target_group_id: - Group ID.
         :param name: - New name of the target group — a string up to 64 characters long.
         :param domain: - Domain of the site where user accounting code will be placed.
-        :param lifetime: - 'Only for the groups that get audience from sites with user accounting code.', Time in days when users added to a retarget group will be automatically excluded from it. '0' – automatic exclusion is off.
+        :param lifetime: - 'Only for the groups that get audience from sites with user accounting code.', Time in days when users added to a retarget group will be automatically excluded from it. '0' - automatic exclusion is off.
         :param target_pixel_id:
         :param target_pixel_rules:
         :param return_raw_response: - return result at dict
@@ -807,5 +943,5 @@ class Ads(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
