@@ -1,13 +1,13 @@
 from vkwave.types.responses import *
-
 from ._category import Category
 from ._utils import get_params
 
 
 class Apps(Category):
     async def delete_app_requests(
-        self, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param return_raw_response: - return result at dict
         :return:
@@ -19,7 +19,7 @@ class Apps(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def get(
@@ -151,7 +151,9 @@ class Apps(Category):
         return result
 
     async def get_scopes(
-        self, return_raw_response: bool = False, type: typing.Optional[str] = None,
+        self,
+        return_raw_response: bool = False,
+        type: typing.Optional[str] = None,
     ) -> typing.Union[dict, AppsGetScopesResponse]:
         """
         :param type:
@@ -169,7 +171,9 @@ class Apps(Category):
         return result
 
     async def get_score(
-        self, user_id: int, return_raw_response: bool = False,
+        self,
+        user_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, AppsGetScoreResponse]:
         """
         :param user_id:
@@ -186,6 +190,50 @@ class Apps(Category):
         result = AppsGetScoreResponse(**raw_result)
         return result
 
+    async def promo_has_active_gift(
+        self,
+        promo_id: int,
+        return_raw_response: bool = False,
+        user_id: typing.Optional[int] = None,
+    ) -> typing.Union[dict, BaseBoolResponse]:
+        """
+        :param promo_id: - Id of game promo action
+        :param user_id:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("promoHasActiveGift", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseBoolResponse(**raw_result)
+        return result
+
+    async def promo_use_gift(
+        self,
+        promo_id: int,
+        return_raw_response: bool = False,
+        user_id: typing.Optional[int] = None,
+    ) -> typing.Union[dict, BaseBoolResponse]:
+        """
+        :param promo_id: - Id of game promo action
+        :param user_id:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("promoUseGift", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseBoolResponse(**raw_result)
+        return result
+
     async def send_request(
         self,
         user_id: int,
