@@ -1,13 +1,14 @@
 from vkwave.types.responses import *
-
 from ._category import Category
 from ._utils import get_params
 
 
 class Fave(Category):
     async def add_article(
-        self, url: str, return_raw_response: bool = False,
-    ) -> typing.Union[dict, BaseBoolResponse]:
+        self,
+        url: str,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param url:
         :param return_raw_response: - return result at dict
@@ -20,12 +21,14 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = BaseBoolResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def add_link(
-        self, link: str, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        link: str,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param link: - Link URL.
         :param return_raw_response: - return result at dict
@@ -38,7 +41,7 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def add_page(
@@ -46,7 +49,7 @@ class Fave(Category):
         return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param user_id:
         :param group_id:
@@ -60,7 +63,7 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def add_post(
@@ -69,7 +72,7 @@ class Fave(Category):
         id: int,
         return_raw_response: bool = False,
         access_key: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id:
         :param id:
@@ -84,7 +87,7 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def add_product(
@@ -93,7 +96,7 @@ class Fave(Category):
         id: int,
         return_raw_response: bool = False,
         access_key: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id:
         :param id:
@@ -108,14 +111,18 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def add_tag(
-        self, return_raw_response: bool = False, name: typing.Optional[str] = None,
+        self,
+        return_raw_response: bool = False,
+        name: typing.Optional[str] = None,
+        position: typing.Optional[str] = None,
     ) -> typing.Union[dict, FaveAddTagResponse]:
         """
         :param name:
+        :param position:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -135,7 +142,7 @@ class Fave(Category):
         id: int,
         return_raw_response: bool = False,
         access_key: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id:
         :param id:
@@ -150,12 +157,15 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def edit_tag(
-        self, id: int, name: str, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        id: int,
+        name: str,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param id:
         :param name:
@@ -169,7 +179,7 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def get(
@@ -237,7 +247,8 @@ class Fave(Category):
         return result
 
     async def get_tags(
-        self, return_raw_response: bool = False,
+        self,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, FaveGetTagsResponse]:
         """
         :param return_raw_response: - return result at dict
@@ -254,7 +265,8 @@ class Fave(Category):
         return result
 
     async def mark_seen(
-        self, return_raw_response: bool = False,
+        self,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, BaseBoolResponse]:
         """
         :param return_raw_response: - return result at dict
@@ -271,7 +283,10 @@ class Fave(Category):
         return result
 
     async def remove_article(
-        self, owner_id: int, article_id: int, return_raw_response: bool = False,
+        self,
+        owner_id: int,
+        article_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, BaseBoolResponse]:
         """
         :param owner_id:
@@ -294,7 +309,7 @@ class Fave(Category):
         return_raw_response: bool = False,
         link_id: typing.Optional[str] = None,
         link: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param link_id: - Link ID (can be obtained by [vk.com/dev/faves.getLinks|faves.getLinks] method).
         :param link: - Link URL
@@ -308,7 +323,7 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def remove_page(
@@ -316,7 +331,7 @@ class Fave(Category):
         return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param user_id:
         :param group_id:
@@ -330,12 +345,15 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def remove_post(
-        self, owner_id: int, id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        owner_id: int,
+        id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id:
         :param id:
@@ -349,12 +367,15 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def remove_product(
-        self, owner_id: int, id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        owner_id: int,
+        id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id:
         :param id:
@@ -368,12 +389,14 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def remove_tag(
-        self, id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param id:
         :param return_raw_response: - return result at dict
@@ -386,12 +409,36 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
+        return result
+
+    async def remove_video(
+        self,
+        owner_id: int,
+        id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
+        """
+        :param owner_id:
+        :param id:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("removeVideo", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def reorder_tags(
-        self, ids: typing.List[int], return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        ids: typing.List[int],
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param ids:
         :param return_raw_response: - return result at dict
@@ -404,7 +451,7 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def set_page_tags(
@@ -413,7 +460,7 @@ class Fave(Category):
         user_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
         tag_ids: typing.Optional[typing.List[int]] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param user_id:
         :param group_id:
@@ -428,7 +475,7 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def set_tags(
@@ -440,7 +487,7 @@ class Fave(Category):
         tag_ids: typing.Optional[typing.List[int]] = None,
         link_id: typing.Optional[str] = None,
         link_url: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param item_type:
         :param item_owner_id:
@@ -458,7 +505,7 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def track_page_interaction(
@@ -466,7 +513,7 @@ class Fave(Category):
         return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param user_id:
         :param group_id:
@@ -480,5 +527,5 @@ class Fave(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
