@@ -1,5 +1,4 @@
 from vkwave.types.responses import *
-
 from ._category import Category
 from ._utils import get_params
 
@@ -9,7 +8,7 @@ class Friends(Category):
         self,
         return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
-        text: typing.Optional[BaseBoolInt] = None,
+        text: typing.Optional[str] = None,
         follow: typing.Optional[BaseBoolInt] = None,
     ) -> typing.Union[dict, FriendsAddResponse]:
         """
@@ -56,10 +55,12 @@ class Friends(Category):
         user_ids: typing.List[int],
         return_raw_response: bool = False,
         need_sign: typing.Optional[BaseBoolInt] = None,
-    ) -> typing.Union[dict, FriendsAreFriendsResponse]:
+        extended: typing.Optional[BaseBoolInt] = None,
+    ) -> typing.Union[dict, FriendsAreFriendsResponse, FriendsAreFriendsExtendedResponse]:
         """
         :param user_ids: - IDs of the users whose friendship status to check.
         :param need_sign: - '1' — to return 'sign' field. 'sign' is md5("{id}_{user_id}_{friends_status}_{application_secret}"), where id is current user ID. This field allows to check that data has not been modified by the client. By default: '0'.
+        :param extended: - Return friend request read_state field
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -70,11 +71,17 @@ class Friends(Category):
         if return_raw_response:
             return raw_result
 
-        result = FriendsAreFriendsResponse(**raw_result)
+        result = (
+            FriendsAreFriendsResponse(**raw_result)
+            if not extended
+            else FriendsAreFriendsExtendedResponse(**raw_result)
+        )
         return result
 
     async def delete(
-        self, return_raw_response: bool = False, user_id: typing.Optional[int] = None,
+        self,
+        return_raw_response: bool = False,
+        user_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, FriendsDeleteResponse]:
         """
         :param user_id: - ID of the user whose friend request is to be declined or who is to be deleted from the current user's friend list.
@@ -92,8 +99,9 @@ class Friends(Category):
         return result
 
     async def delete_all_requests(
-        self, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param return_raw_response: - return result at dict
         :return:
@@ -105,12 +113,14 @@ class Friends(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def delete_list(
-        self, list_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        list_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param list_id: - ID of the friend list to delete.
         :param return_raw_response: - return result at dict
@@ -123,7 +133,7 @@ class Friends(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def edit(
@@ -131,7 +141,7 @@ class Friends(Category):
         user_id: int,
         return_raw_response: bool = False,
         list_ids: typing.Optional[typing.List[int]] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param user_id: - ID of the user whose friend list is to be edited.
         :param list_ids: - IDs of the friend lists to which to add the user.
@@ -145,7 +155,7 @@ class Friends(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def edit_list(
@@ -156,7 +166,7 @@ class Friends(Category):
         user_ids: typing.Optional[typing.List[int]] = None,
         add_user_ids: typing.Optional[typing.List[int]] = None,
         delete_user_ids: typing.Optional[typing.List[int]] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param name: - Name of the friend list.
         :param list_id: - Friend list ID.
@@ -173,7 +183,7 @@ class Friends(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def get(
@@ -187,7 +197,7 @@ class Friends(Category):
         fields: typing.Optional[typing.List[UsersFields]] = None,
         name_case: typing.Optional[str] = None,
         ref: typing.Optional[str] = None,
-    ) -> typing.Union[dict, FriendsGetResponse]:
+    ) -> typing.Union[dict, FriendsGetResponse, FriendsGetFieldsResponse]:
         """
         :param user_id: - User ID. By default, the current user ID.
         :param order: - Sort order: , 'name' — by name (enabled only if the 'fields' parameter is used), 'hints' — by rating, similar to how friends are sorted in My friends section, , This parameter is available only for [vk.com/dev/standalone|desktop applications].
@@ -207,11 +217,16 @@ class Friends(Category):
         if return_raw_response:
             return raw_result
 
-        result = FriendsGetResponse(**raw_result)
+        result = (
+            FriendsGetResponse(**raw_result)
+            if not fields
+            else FriendsGetFieldsResponse(**raw_result)
+        )
         return result
 
     async def get_app_users(
-        self, return_raw_response: bool = False,
+        self,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, FriendsGetAppUsersResponse]:
         """
         :param return_raw_response: - return result at dict
@@ -332,7 +347,9 @@ class Friends(Category):
         return result
 
     async def get_recent(
-        self, return_raw_response: bool = False, count: typing.Optional[int] = None,
+        self,
+        return_raw_response: bool = False,
+        count: typing.Optional[int] = None,
     ) -> typing.Union[dict, FriendsGetRecentResponse]:
         """
         :param count: - Number of recently added friends to return.
@@ -353,11 +370,11 @@ class Friends(Category):
         self,
         return_raw_response: bool = False,
         offset: typing.Optional[int] = None,
-        count: typing.Optional[BaseBoolInt] = None,
+        count: typing.Optional[int] = None,
         extended: typing.Optional[BaseBoolInt] = None,
         need_mutual: typing.Optional[BaseBoolInt] = None,
         out: typing.Optional[BaseBoolInt] = None,
-        sort: typing.Optional[BaseBoolInt] = None,
+        sort: typing.Optional[int] = None,
         need_viewed: typing.Optional[bool] = None,
         suggested: typing.Optional[BaseBoolInt] = None,
         ref: typing.Optional[str] = None,
