@@ -1,5 +1,4 @@
 from vkwave.types.responses import *
-
 from ._category import Category
 from ._utils import get_params
 
@@ -100,8 +99,11 @@ class Groups(Category):
         return result
 
     async def approve_request(
-        self, group_id: int, user_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        group_id: int,
+        user_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Community ID.
         :param user_id: - User ID.
@@ -115,7 +117,7 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def ban(
@@ -127,7 +129,7 @@ class Groups(Category):
         reason: typing.Optional[int] = None,
         comment: typing.Optional[str] = None,
         comment_visible: typing.Optional[bool] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id:
         :param owner_id:
@@ -145,7 +147,7 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def create(
@@ -176,9 +178,34 @@ class Groups(Category):
         result = GroupsCreateResponse(**raw_result)
         return result
 
+    async def delete_address(
+        self,
+        group_id: int,
+        address_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
+        """
+        :param group_id:
+        :param address_id:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("deleteAddress", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseOkResponse(**raw_result)
+        return result
+
     async def delete_callback_server(
-        self, group_id: int, server_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        group_id: int,
+        server_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id:
         :param server_id:
@@ -192,12 +219,15 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def delete_link(
-        self, group_id: int, link_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        group_id: int,
+        link_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Community ID.
         :param link_id: - Link ID.
@@ -211,12 +241,14 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def disable_online(
-        self, group_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id:
         :param return_raw_response: - return result at dict
@@ -229,7 +261,7 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def edit(
@@ -239,9 +271,9 @@ class Groups(Category):
         title: typing.Optional[str] = None,
         description: typing.Optional[str] = None,
         screen_name: typing.Optional[str] = None,
-        access: typing.Optional[BaseBoolInt] = None,
+        access: typing.Optional[int] = None,
         website: typing.Optional[str] = None,
-        subject: typing.Optional[BaseBoolInt] = None,
+        subject: typing.Optional[str] = None,
         email: typing.Optional[str] = None,
         phone: typing.Optional[str] = None,
         rss: typing.Optional[str] = None,
@@ -251,17 +283,17 @@ class Groups(Category):
         public_category: typing.Optional[int] = None,
         public_subcategory: typing.Optional[int] = None,
         public_date: typing.Optional[str] = None,
-        wall: typing.Optional[BaseBoolInt] = None,
-        topics: typing.Optional[BaseBoolInt] = None,
-        photos: typing.Optional[BaseBoolInt] = None,
-        video: typing.Optional[BaseBoolInt] = None,
-        audio: typing.Optional[BaseBoolInt] = None,
+        wall: typing.Optional[int] = None,
+        topics: typing.Optional[int] = None,
+        photos: typing.Optional[int] = None,
+        video: typing.Optional[int] = None,
+        audio: typing.Optional[int] = None,
         links: typing.Optional[BaseBoolInt] = None,
         events: typing.Optional[BaseBoolInt] = None,
         places: typing.Optional[BaseBoolInt] = None,
         contacts: typing.Optional[BaseBoolInt] = None,
-        docs: typing.Optional[BaseBoolInt] = None,
-        wiki: typing.Optional[BaseBoolInt] = None,
+        docs: typing.Optional[int] = None,
+        wiki: typing.Optional[int] = None,
         messages: typing.Optional[BaseBoolInt] = None,
         articles: typing.Optional[bool] = None,
         addresses: typing.Optional[bool] = None,
@@ -270,8 +302,8 @@ class Groups(Category):
         market_comments: typing.Optional[BaseBoolInt] = None,
         market_country: typing.Optional[typing.List[int]] = None,
         market_city: typing.Optional[typing.List[int]] = None,
-        market_currency: typing.Optional[BaseBoolInt] = None,
-        market_contact: typing.Optional[BaseBoolInt] = None,
+        market_currency: typing.Optional[int] = None,
+        market_contact: typing.Optional[int] = None,
         market_wiki: typing.Optional[int] = None,
         obscene_filter: typing.Optional[BaseBoolInt] = None,
         obscene_stopwords: typing.Optional[BaseBoolInt] = None,
@@ -280,7 +312,7 @@ class Groups(Category):
         secondary_section: typing.Optional[int] = None,
         country: typing.Optional[int] = None,
         city: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Community ID.
         :param title: - Community title.
@@ -337,7 +369,7 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def edit_address(
@@ -394,7 +426,7 @@ class Groups(Category):
         title: str,
         return_raw_response: bool = False,
         secret_key: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id:
         :param server_id:
@@ -411,7 +443,7 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def edit_link(
@@ -420,7 +452,7 @@ class Groups(Category):
         link_id: int,
         return_raw_response: bool = False,
         text: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Community ID.
         :param link_id: - Link ID.
@@ -435,7 +467,7 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def edit_manager(
@@ -448,11 +480,11 @@ class Groups(Category):
         contact_position: typing.Optional[str] = None,
         contact_phone: typing.Optional[str] = None,
         contact_email: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Community ID.
         :param user_id: - User ID.
-        :param role: - Manager role. Possible values: *'moderator',, *'editor',, *'administrator'.
+        :param role: - Manager role. Possible values: *'moderator',, *'editor',, *'administrator',, *'advertiser'.
         :param is_contact: - '1' — to show the manager in Contacts block of the community.
         :param contact_position: - Position to show in Contacts block.
         :param contact_phone: - Contact phone.
@@ -467,12 +499,14 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def enable_online(
-        self, group_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id:
         :param return_raw_response: - return result at dict
@@ -485,7 +519,7 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def get(
@@ -588,7 +622,7 @@ class Groups(Category):
         group_ids: typing.Optional[typing.List[str]] = None,
         group_id: typing.Optional[str] = None,
         fields: typing.Optional[typing.List[GroupsFields]] = None,
-    ) -> typing.Union[dict, GroupsGetByIdResponse]:
+    ) -> typing.Union[dict, GroupsGetByIdLegacyResponse]:
         """
         :param group_ids: - IDs or screen names of communities.
         :param group_id: - ID or screen name of the community.
@@ -603,11 +637,13 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = GroupsGetByIdResponse(**raw_result)
+        result = GroupsGetByIdLegacyResponse(**raw_result)
         return result
 
     async def get_callback_confirmation_code(
-        self, group_id: int, return_raw_response: bool = False,
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetCallbackConfirmationCodeResponse]:
         """
         :param group_id: - Community ID.
@@ -773,7 +809,9 @@ class Groups(Category):
         return result
 
     async def get_long_poll_server(
-        self, group_id: int, return_raw_response: bool = False,
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetLongPollServerResponse]:
         """
         :param group_id: - Community ID
@@ -791,7 +829,9 @@ class Groups(Category):
         return result
 
     async def get_long_poll_settings(
-        self, group_id: int, return_raw_response: bool = False,
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetLongPollSettingsResponse]:
         """
         :param group_id: - Community ID.
@@ -817,7 +857,7 @@ class Groups(Category):
         count: typing.Optional[int] = None,
         fields: typing.Optional[typing.List[UsersFields]] = None,
         filter: typing.Optional[str] = None,
-    ) -> typing.Union[dict, GroupsGetMembersResponse]:
+    ) -> typing.Union[dict, GroupsGetMembersResponse, GroupsGetMembersFieldsResponse]:
         """
         :param group_id: - ID or screen name of the community.
         :param sort: - Sort order. Available values: 'id_asc', 'id_desc', 'time_asc', 'time_desc'. 'time_asc' and 'time_desc' are availavle only if the method is called by the group's 'moderator'.
@@ -835,7 +875,11 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = GroupsGetMembersResponse(**raw_result)
+        result = (
+            GroupsGetMembersResponse(**raw_result)
+            if not fields and (not filter or filter != "managers")
+            else GroupsGetMembersFieldsResponse(**raw_result)
+        )
         return result
 
     async def get_requests(
@@ -845,7 +889,7 @@ class Groups(Category):
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         fields: typing.Optional[typing.List[UsersFields]] = None,
-    ) -> typing.Union[dict, GroupsGetRequestsResponse]:
+    ) -> typing.Union[dict, GroupsGetRequestsResponse, GroupsGetRequestsFieldsResponse]:
         """
         :param group_id: - Community ID.
         :param offset: - Offset needed to return a specific subset of results.
@@ -861,11 +905,17 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = GroupsGetRequestsResponse(**raw_result)
+        result = (
+            GroupsGetRequestsResponse(**raw_result)
+            if not fields
+            else GroupsGetRequestsFieldsResponse(**raw_result)
+        )
         return result
 
     async def get_settings(
-        self, group_id: int, return_raw_response: bool = False,
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetSettingsResponse]:
         """
         :param group_id: - Community ID.
@@ -882,8 +932,29 @@ class Groups(Category):
         result = GroupsGetSettingsResponse(**raw_result)
         return result
 
+    async def get_tag_list(
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, GroupsGetTagListResponse]:
+        """
+        :param group_id:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("getTagList", params)
+        if return_raw_response:
+            return raw_result
+
+        result = GroupsGetTagListResponse(**raw_result)
+        return result
+
     async def get_token_permissions(
-        self, return_raw_response: bool = False,
+        self,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetTokenPermissionsResponse]:
         """
         :param return_raw_response: - return result at dict
@@ -900,8 +971,11 @@ class Groups(Category):
         return result
 
     async def invite(
-        self, group_id: int, user_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        group_id: int,
+        user_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Community ID.
         :param user_id: - User ID.
@@ -915,7 +989,7 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def is_member(
@@ -952,8 +1026,8 @@ class Groups(Category):
         self,
         return_raw_response: bool = False,
         group_id: typing.Optional[int] = None,
-        not_sure: typing.Optional[BaseBoolInt] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        not_sure: typing.Optional[str] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - ID or screen name of the community.
         :param not_sure: - Optional parameter which is taken into account when 'gid' belongs to the event: '1' — Perhaps I will attend, '0' — I will be there for sure (default), ,
@@ -967,12 +1041,14 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def leave(
-        self, group_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - ID or screen name of the community.
         :param return_raw_response: - return result at dict
@@ -985,12 +1061,15 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def remove_user(
-        self, group_id: int, user_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        group_id: int,
+        user_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Community ID.
         :param user_id: - User ID.
@@ -1004,7 +1083,7 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def reorder_link(
@@ -1013,7 +1092,7 @@ class Groups(Category):
         link_id: int,
         return_raw_response: bool = False,
         after: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Community ID.
         :param link_id: - Link ID.
@@ -1028,7 +1107,7 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def search(
@@ -1040,7 +1119,7 @@ class Groups(Category):
         city_id: typing.Optional[int] = None,
         future: typing.Optional[BaseBoolInt] = None,
         market: typing.Optional[BaseBoolInt] = None,
-        sort: typing.Optional[BaseBoolInt] = None,
+        sort: typing.Optional[int] = None,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
     ) -> typing.Union[dict, GroupsSearchResponse]:
@@ -1104,6 +1183,8 @@ class Groups(Category):
         market_comment_edit: typing.Optional[BaseBoolInt] = None,
         market_comment_delete: typing.Optional[BaseBoolInt] = None,
         market_comment_restore: typing.Optional[BaseBoolInt] = None,
+        market_order_new: typing.Optional[bool] = None,
+        market_order_edit: typing.Optional[bool] = None,
         poll_vote_new: typing.Optional[BaseBoolInt] = None,
         group_join: typing.Optional[BaseBoolInt] = None,
         group_leave: typing.Optional[BaseBoolInt] = None,
@@ -1113,7 +1194,17 @@ class Groups(Category):
         user_block: typing.Optional[bool] = None,
         user_unblock: typing.Optional[bool] = None,
         lead_forms_new: typing.Optional[bool] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        like_add: typing.Optional[bool] = None,
+        like_remove: typing.Optional[bool] = None,
+        message_event: typing.Optional[bool] = None,
+        donut_subscription_create: typing.Optional[bool] = None,
+        donut_subscription_prolonged: typing.Optional[bool] = None,
+        donut_subscription_cancelled: typing.Optional[bool] = None,
+        donut_subscription_price_changed: typing.Optional[bool] = None,
+        donut_subscription_expired: typing.Optional[bool] = None,
+        donut_money_withdraw: typing.Optional[bool] = None,
+        donut_money_withdraw_error: typing.Optional[bool] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Community ID.
         :param server_id: - Server ID.
@@ -1149,6 +1240,8 @@ class Groups(Category):
         :param market_comment_edit: - A market comment has been edited ('0' — disabled, '1' — enabled).
         :param market_comment_delete: - A market comment has been deleted ('0' — disabled, '1' — enabled).
         :param market_comment_restore: - A market comment has been restored ('0' — disabled, '1' — enabled).
+        :param market_order_new:
+        :param market_order_edit:
         :param poll_vote_new: - A vote in a public poll has been added ('0' — disabled, '1' — enabled).
         :param group_join: - Joined community notifications ('0' — disabled, '1' — enabled).
         :param group_leave: - Left community notifications ('0' — disabled, '1' — enabled).
@@ -1158,6 +1251,16 @@ class Groups(Category):
         :param user_block: - User added to community blacklist
         :param user_unblock: - User removed from community blacklist
         :param lead_forms_new: - New form in lead forms
+        :param like_add:
+        :param like_remove:
+        :param message_event:
+        :param donut_subscription_create:
+        :param donut_subscription_prolonged:
+        :param donut_subscription_cancelled:
+        :param donut_subscription_price_changed:
+        :param donut_subscription_expired:
+        :param donut_money_withdraw:
+        :param donut_money_withdraw_error:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -1168,7 +1271,7 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def set_long_poll_settings(
@@ -1216,7 +1319,17 @@ class Groups(Category):
         group_officers_edit: typing.Optional[bool] = None,
         user_block: typing.Optional[bool] = None,
         user_unblock: typing.Optional[bool] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        like_add: typing.Optional[bool] = None,
+        like_remove: typing.Optional[bool] = None,
+        message_event: typing.Optional[bool] = None,
+        donut_subscription_create: typing.Optional[bool] = None,
+        donut_subscription_prolonged: typing.Optional[bool] = None,
+        donut_subscription_cancelled: typing.Optional[bool] = None,
+        donut_subscription_price_changed: typing.Optional[bool] = None,
+        donut_subscription_expired: typing.Optional[bool] = None,
+        donut_money_withdraw: typing.Optional[bool] = None,
+        donut_money_withdraw_error: typing.Optional[bool] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Community ID.
         :param enabled: - Sets whether Long Poll is enabled ('0' — disabled, '1' — enabled).
@@ -1260,6 +1373,16 @@ class Groups(Category):
         :param group_officers_edit:
         :param user_block: - User added to community blacklist
         :param user_unblock: - User removed from community blacklist
+        :param like_add:
+        :param like_remove:
+        :param message_event:
+        :param donut_subscription_create:
+        :param donut_subscription_prolonged:
+        :param donut_subscription_cancelled:
+        :param donut_subscription_price_changed:
+        :param donut_subscription_expired:
+        :param donut_money_withdraw:
+        :param donut_money_withdraw_error:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -1270,7 +1393,177 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
+        return result
+
+    async def set_settings(
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
+        messages: typing.Optional[bool] = None,
+        bots_capabilities: typing.Optional[bool] = None,
+        bots_start_button: typing.Optional[bool] = None,
+        bots_add_to_chat: typing.Optional[bool] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
+        """
+        :param group_id:
+        :param messages:
+        :param bots_capabilities:
+        :param bots_start_button:
+        :param bots_add_to_chat:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("setSettings", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseOkResponse(**raw_result)
+        return result
+
+    async def set_user_note(
+        self,
+        group_id: int,
+        user_id: int,
+        return_raw_response: bool = False,
+        note: typing.Optional[str] = None,
+    ) -> typing.Union[dict, BaseBoolResponse]:
+        """
+        :param group_id:
+        :param user_id:
+        :param note: - Note body
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("setUserNote", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseBoolResponse(**raw_result)
+        return result
+
+    async def tag_add(
+        self,
+        group_id: int,
+        tag_name: str,
+        return_raw_response: bool = False,
+        tag_color: typing.Optional[str] = None,
+    ) -> typing.Union[dict, BaseBoolResponse]:
+        """
+        :param group_id:
+        :param tag_name:
+        :param tag_color:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("tagAdd", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseBoolResponse(**raw_result)
+        return result
+
+    async def tag_bind(
+        self,
+        group_id: int,
+        tag_id: int,
+        user_id: int,
+        act: str,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseBoolResponse]:
+        """
+        :param group_id:
+        :param tag_id:
+        :param user_id:
+        :param act: - Describe the action
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("tagBind", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseBoolResponse(**raw_result)
+        return result
+
+    async def tag_delete(
+        self,
+        group_id: int,
+        tag_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseBoolResponse]:
+        """
+        :param group_id:
+        :param tag_id:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("tagDelete", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseBoolResponse(**raw_result)
+        return result
+
+    async def tag_update(
+        self,
+        group_id: int,
+        tag_id: int,
+        tag_name: str,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseBoolResponse]:
+        """
+        :param group_id:
+        :param tag_id:
+        :param tag_name:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("tagUpdate", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseBoolResponse(**raw_result)
+        return result
+
+    async def toggle_market(
+        self,
+        group_id: int,
+        state: str,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
+        """
+        :param group_id:
+        :param state:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("toggleMarket", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def unban(
@@ -1278,7 +1571,7 @@ class Groups(Category):
         group_id: int,
         return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id:
         :param owner_id:
@@ -1292,5 +1585,5 @@ class Groups(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
