@@ -1,5 +1,4 @@
 from vkwave.types.responses import *
-
 from ._category import Category
 from ._utils import get_params
 
@@ -11,13 +10,18 @@ class Market(Category):
         name: str,
         description: str,
         category_id: int,
-        main_photo_id: int,
         return_raw_response: bool = False,
         price: typing.Optional[int] = None,
         old_price: typing.Optional[int] = None,
         deleted: typing.Optional[BaseBoolInt] = None,
+        main_photo_id: typing.Optional[int] = None,
         photo_ids: typing.Optional[typing.List[int]] = None,
         url: typing.Optional[str] = None,
+        dimension_width: typing.Optional[int] = None,
+        dimension_height: typing.Optional[int] = None,
+        dimension_length: typing.Optional[int] = None,
+        weight: typing.Optional[int] = None,
+        sku: typing.Optional[str] = None
     ) -> typing.Union[dict, MarketAddResponse]:
         """
         :param owner_id: - ID of an item owner community.
@@ -30,6 +34,11 @@ class Market(Category):
         :param main_photo_id: - Cover photo ID.
         :param photo_ids: - IDs of additional photos.
         :param url: - Url for button in market item.
+        :param dimension_width:
+        :param dimension_height:
+        :param dimension_length:
+        :param weight:
+        :param sku: - string, maximum length 50
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -75,7 +84,7 @@ class Market(Category):
         item_id: int,
         album_ids: typing.List[int],
         return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an item owner community.
         :param item_id: - Item ID.
@@ -90,7 +99,7 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def create_comment(
@@ -128,8 +137,11 @@ class Market(Category):
         return result
 
     async def delete(
-        self, owner_id: int, item_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        owner_id: int,
+        item_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an item owner community.
         :param item_id: - Item ID.
@@ -143,12 +155,15 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def delete_album(
-        self, owner_id: int, album_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        owner_id: int,
+        album_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an collection owner community.
         :param album_id: - Collection ID.
@@ -162,11 +177,14 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def delete_comment(
-        self, owner_id: int, comment_id: int, return_raw_response: bool = False,
+        self,
+        owner_id: int,
+        comment_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, MarketDeleteCommentResponse]:
         """
         :param owner_id: - identifier of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
@@ -197,7 +215,8 @@ class Market(Category):
         deleted: typing.Optional[BaseBoolInt] = None,
         photo_ids: typing.Optional[typing.List[int]] = None,
         url: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        sku: typing.Optional[str] = None
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an item owner community.
         :param item_id: - Item ID.
@@ -209,6 +228,7 @@ class Market(Category):
         :param main_photo_id: - Cover photo ID.
         :param photo_ids: - IDs of additional photos.
         :param url: - Url for button in market item.
+        :param sku: - string, maximum length 50
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -219,7 +239,7 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def edit_album(
@@ -230,7 +250,7 @@ class Market(Category):
         return_raw_response: bool = False,
         photo_id: typing.Optional[int] = None,
         main_album: typing.Optional[BaseBoolInt] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an collection owner community.
         :param album_id: - Collection ID.
@@ -247,7 +267,7 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def edit_comment(
@@ -255,9 +275,9 @@ class Market(Category):
         owner_id: int,
         comment_id: int,
         return_raw_response: bool = False,
-        message: typing.Optional[BaseBoolInt] = None,
+        message: typing.Optional[str] = None,
         attachments: typing.Optional[typing.List[str]] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an item owner community.
         :param comment_id: - Comment ID.
@@ -273,7 +293,51 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
+        return result
+
+    async def edit_order(
+        self,
+        user_id: int,
+        order_id: int,
+        return_raw_response: bool = False,
+        merchant_comment: typing.Optional[str] = None,
+        status: typing.Optional[int] = None,
+        track_number: typing.Optional[str] = None,
+        payment_status: typing.Optional[str] = None,
+        delivery_price: typing.Optional[int] = None,
+        width: typing.Optional[int] = None,
+        lenght: typing.Optional[int] = None,
+        height: typing.Optional[int] = None,
+        weight: typing.Optional[int] = None,
+        comment_for_user: typing.Optional[str] = None,
+        receipt_link: typing.Optional[str] = None
+    ) -> typing.Union[dict, BaseOkResponse]:
+        """
+        :param user_id: - int (number), minimum value 1, required parameter
+        :param order_id: - positive number, required parameter
+        :param merchant_comment: - string, maximum length 800
+        :param status: - positive number
+        :param track_number: - string, maximum length 60, accessible for versions from 5.130
+        :param payment_status: - string, accessible for versions from 5.130
+        :param delivery_price: - positive number, accessible for versions from 5.130
+        :param width: - positive number, maximum value 100000, accessible for versions from 5.130
+        :param lenght: - positive number, maximum value 100000, accessible for versions from 5.130
+        :param height: - positive number, maximum value 100000, accessible for versions from 5.130
+        :param weight: - positive number, maximum value 100000000, accessible for versions from 5.13
+        :param comment_for_user: - string, maximum length 400, accessible for versions from 5.139
+        :param receipt_link: - string, maximum length 400, accessible for versions from 5.159
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("editOrder", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def get(
@@ -309,7 +373,10 @@ class Market(Category):
         return result
 
     async def get_album_by_id(
-        self, owner_id: int, album_ids: typing.List[int], return_raw_response: bool = False,
+        self,
+        owner_id: int,
+        album_ids: typing.List[int],
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, MarketGetAlbumByIdResponse]:
         """
         :param owner_id: - identifier of an album owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
@@ -382,7 +449,7 @@ class Market(Category):
         return_raw_response: bool = False,
         count: typing.Optional[int] = None,
         offset: typing.Optional[int] = None,
-    ) -> typing.Union[dict, MarketGetCategoriesResponse]:
+    ) -> typing.Union[dict, MarketGetCategoriesNewResponse]:
         """
         :param count: - Number of results to return.
         :param offset: - Offset needed to return a specific subset of results.
@@ -396,7 +463,7 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = MarketGetCategoriesResponse(**raw_result)
+        result = MarketGetCategoriesNewResponse(**raw_result)
         return result
 
     async def get_comments(
@@ -435,13 +502,115 @@ class Market(Category):
         result = MarketGetCommentsResponse(**raw_result)
         return result
 
+    async def get_group_orders(
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
+        offset: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+    ) -> typing.Union[dict, MarketGetGroupOrdersResponse]:
+        """
+        :param group_id:
+        :param offset:
+        :param count:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("getGroupOrders", params)
+        if return_raw_response:
+            return raw_result
+
+        result = MarketGetGroupOrdersResponse(**raw_result)
+        return result
+
+    async def get_order_by_id(
+        self,
+        order_id: int,
+        return_raw_response: bool = False,
+        user_id: typing.Optional[int] = None,
+        extended: typing.Optional[BaseBoolInt] = None,
+    ) -> typing.Union[dict, MarketGetOrderByIdResponse]:
+        """
+        :param user_id:
+        :param order_id:
+        :param extended:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("getOrderById", params)
+        if return_raw_response:
+            return raw_result
+
+        result = MarketGetOrderByIdResponse(**raw_result)
+        return result
+
+    async def get_order_items(
+        self,
+        order_id: int,
+        return_raw_response: bool = False,
+        offset: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+        user_id: typing.Optional[int] = None
+    ) -> typing.Union[dict, MarketGetOrderItemsResponse]:
+        """
+        :param order_id:
+        :param offset:
+        :param count:
+        :param user_id:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("getOrderItems", params)
+        if return_raw_response:
+            return raw_result
+
+        result = MarketGetOrderItemsResponse(**raw_result)
+        return result
+
+    async def get_orders(
+        self,
+        return_raw_response: bool = False,
+        offset: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+        extended: typing.Optional[BaseBoolInt] = None,
+    ) -> typing.Union[dict, MarketGetOrdersResponse, MarketGetOrdersExtendedResponse]:
+        """
+        :param offset:
+        :param count:
+        :param extended:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("getOrders", params)
+        if return_raw_response:
+            return raw_result
+
+        result = (
+            MarketGetOrdersResponse(**raw_result)
+            if not extended
+            else MarketGetOrdersExtendedResponse(**raw_result)
+        )
+        return result
+
     async def remove_from_album(
         self,
         owner_id: int,
         item_id: int,
         album_ids: typing.List[int],
         return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an item owner community.
         :param item_id: - Item ID.
@@ -456,7 +625,7 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def reorder_albums(
@@ -466,7 +635,7 @@ class Market(Category):
         return_raw_response: bool = False,
         before: typing.Optional[int] = None,
         after: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an item owner community.
         :param album_id: - Collection ID.
@@ -482,7 +651,7 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def reorder_items(
@@ -490,10 +659,10 @@ class Market(Category):
         owner_id: int,
         item_id: int,
         return_raw_response: bool = False,
-        album_id: typing.Optional[BaseBoolInt] = None,
+        album_id: typing.Optional[int] = None,
         before: typing.Optional[int] = None,
         after: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an item owner community.
         :param album_id: - ID of a collection to reorder items in. Set 0 to reorder full items list.
@@ -510,7 +679,7 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def report(
@@ -518,8 +687,8 @@ class Market(Category):
         owner_id: int,
         item_id: int,
         return_raw_response: bool = False,
-        reason: typing.Optional[BaseBoolInt] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        reason: typing.Optional[int] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an item owner community.
         :param item_id: - Item ID.
@@ -534,16 +703,16 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def report_comment(
         self,
         owner_id: int,
         comment_id: int,
-        reason: BaseBoolInt,
+        reason: int,
         return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an item owner community.
         :param comment_id: - Comment ID.
@@ -558,12 +727,15 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def restore(
-        self, owner_id: int, item_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        owner_id: int,
+        item_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of an item owner community.
         :param item_id: - Deleted item ID.
@@ -577,11 +749,14 @@ class Market(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def restore_comment(
-        self, owner_id: int, comment_id: int, return_raw_response: bool = False,
+        self,
+        owner_id: int,
+        comment_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, MarketRestoreCommentResponse]:
         """
         :param owner_id: - identifier of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
@@ -607,9 +782,8 @@ class Market(Category):
         q: typing.Optional[str] = None,
         price_from: typing.Optional[int] = None,
         price_to: typing.Optional[int] = None,
-        tags: typing.Optional[typing.List[int]] = None,
         sort: typing.Optional[int] = None,
-        rev: typing.Optional[BaseBoolInt] = None,
+        rev: typing.Optional[int] = None,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         extended: typing.Optional[BaseBoolInt] = None,
@@ -621,7 +795,6 @@ class Market(Category):
         :param q: - Search query, for example "pink slippers".
         :param price_from: - Minimum item price value.
         :param price_to: - Maximum item price value.
-        :param tags: - Comma-separated tag IDs list.
         :param sort:
         :param rev: - '0' — do not use reverse order, '1' — use reverse order
         :param offset: - Offset needed to return a specific subset of results.
