@@ -1,7 +1,7 @@
 from vkwave.types.responses import *
-
 from ._category import Category
 from ._utils import get_params
+from ...types.extension_responses import MessagesSendPeerIdsResponse
 
 
 class Messages(Category):
@@ -10,10 +10,12 @@ class Messages(Category):
         chat_id: int,
         return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        visible_messages_count: typing.Optional[int] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param chat_id: - Chat ID.
         :param user_id: - ID of the user to be added to the chat.
+        :param visible_messages_count:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -24,12 +26,15 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def allow_messages_from_group(
-        self, group_id: int, return_raw_response: bool = False, key: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
+        key: typing.Optional[str] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Group ID.
         :param key:
@@ -43,7 +48,7 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def create_chat(
@@ -51,10 +56,12 @@ class Messages(Category):
         return_raw_response: bool = False,
         user_ids: typing.Optional[typing.List[int]] = None,
         title: typing.Optional[str] = None,
+        group_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, MessagesCreateChatResponse]:
         """
         :param user_ids: - IDs of the users to be added to the chat.
         :param title: - Chat title.
+        :param group_id:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -75,12 +82,16 @@ class Messages(Category):
         spam: typing.Optional[BaseBoolInt] = None,
         group_id: typing.Optional[int] = None,
         delete_for_all: typing.Optional[BaseBoolInt] = None,
+        peer_id: typing.Optional[int] = None,
+        conversation_message_ids: typing.Optional[typing.List[int]] = None,
     ) -> typing.Union[dict, MessagesDeleteResponse]:
         """
         :param message_ids: - Message IDs.
         :param spam: - '1' — to mark message as spam.
         :param group_id: - Group ID (for group messages with user access token)
         :param delete_for_all: - '1' — delete message for for all.
+        :param peer_id:
+        :params conversation_message_ids:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -120,7 +131,7 @@ class Messages(Category):
         self,
         return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
-        peer_id: typing.Optional[BaseBoolInt] = None,
+        peer_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, MessagesDeleteConversationResponse]:
         """
@@ -141,8 +152,10 @@ class Messages(Category):
         return result
 
     async def deny_messages_from_group(
-        self, group_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        group_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param group_id: - Group ID.
         :param return_raw_response: - return result at dict
@@ -155,27 +168,30 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def edit(
         self,
-        peer_id: BaseBoolInt,
-        message_id: int,
+        peer_id: int,
         return_raw_response: bool = False,
         message: typing.Optional[str] = None,
-        lat: typing.Optional[BaseBoolInt] = None,
-        long: typing.Optional[BaseBoolInt] = None,
-        attachment: typing.Optional[BaseBoolInt] = None,
+        lat: typing.Optional[int] = None,
+        long: typing.Optional[int] = None,
+        attachment: typing.Optional[str] = None,
         keep_forward_messages: typing.Optional[BaseBoolInt] = None,
         keep_snippets: typing.Optional[BaseBoolInt] = None,
         group_id: typing.Optional[int] = None,
         dont_parse_links: typing.Optional[bool] = None,
+        disable_mentions: typing.Optional[bool] = None,
+        message_id: typing.Optional[int] = None,
+        conversation_message_id: typing.Optional[int] = None,
+        template: typing.Optional[str] = None,
+        keyboard: typing.Optional[str] = None,
     ) -> typing.Union[dict, MessagesEditResponse]:
         """
         :param peer_id: - Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
         :param message: - (Required if 'attachments' is not set.) Text of the message.
-        :param message_id:
         :param lat: - Geographical latitude of a check-in, in degrees (from -90 to 90).
         :param long: - Geographical longitude of a check-in, in degrees (from -180 to 180).
         :param attachment: - (Required if 'message' is not set.) List of objects attached to the message, separated by commas, in the following format: "<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, 'wall' — wall post, '<owner_id>' — ID of the media attachment owner. '<media_id>' — media attachment ID. Example: "photo100172_166443618"
@@ -183,6 +199,11 @@ class Messages(Category):
         :param keep_snippets: - '1' — to keep attached snippets.
         :param group_id: - Group ID (for group messages with user access token)
         :param dont_parse_links:
+        :param disable_mentions:
+        :param message_id:
+        :param conversation_message_id:
+        :param template:
+        :param keyboard:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -197,8 +218,11 @@ class Messages(Category):
         return result
 
     async def edit_chat(
-        self, chat_id: int, title: str, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        chat_id: int,
+        return_raw_response: bool = False,
+        title: typing.Optional[str] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param chat_id: - Chat ID.
         :param title: - New title of the chat.
@@ -212,12 +236,12 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def get_by_conversation_message_id(
         self,
-        peer_id: BaseBoolInt,
+        peer_id: int,
         conversation_message_ids: typing.List[int],
         return_raw_response: bool = False,
         extended: typing.Optional[BaseBoolInt] = None,
@@ -247,7 +271,7 @@ class Messages(Category):
         self,
         message_ids: typing.List[int],
         return_raw_response: bool = False,
-        preview_length: typing.Optional[BaseBoolInt] = None,
+        preview_length: typing.Optional[int] = None,
         extended: typing.Optional[BaseBoolInt] = None,
         fields: typing.Optional[typing.List[UsersFields]] = None,
         group_id: typing.Optional[int] = None,
@@ -363,7 +387,9 @@ class Messages(Category):
         fields: typing.Optional[typing.List[BaseUserGroupFields]] = None,
         group_id: typing.Optional[int] = None,
     ) -> typing.Union[
-        dict, MessagesGetConversationsByIdResponse, MessagesGetConversationsByIdExtendedResponse,
+        dict,
+        MessagesGetConversationsByIdResponse,
+        MessagesGetConversationsByIdExtendedResponse,
     ]:
         """
         :param peer_ids: - Destination IDs. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
@@ -395,7 +421,7 @@ class Messages(Category):
         user_id: typing.Optional[int] = None,
         peer_id: typing.Optional[int] = None,
         start_message_id: typing.Optional[int] = None,
-        rev: typing.Optional[BaseBoolInt] = None,
+        rev: typing.Optional[int] = None,
         extended: typing.Optional[BaseBoolInt] = None,
         fields: typing.Optional[typing.List[UsersFields]] = None,
         group_id: typing.Optional[int] = None,
@@ -425,7 +451,7 @@ class Messages(Category):
 
     async def get_history_attachments(
         self,
-        peer_id: BaseBoolInt,
+        peer_id: int,
         return_raw_response: bool = False,
         media_type: typing.Optional[str] = None,
         start_from: typing.Optional[str] = None,
@@ -442,7 +468,7 @@ class Messages(Category):
         :param start_from: - Message ID to start return results from.
         :param count: - Number of objects to return.
         :param photo_sizes: - '1' — to return photo sizes in a
-        :param fields: - Additional profile [vk.com/dev/fields|fields] to return. 
+        :param fields: - Additional profile [vk.com/dev/fields|fields] to return.
         :param group_id: - Group ID (for group messages with group access token)
         :param preserve_order:
         :param max_forwards_level:
@@ -459,6 +485,46 @@ class Messages(Category):
         result = MessagesGetHistoryAttachmentsResponse(**raw_result)
         return result
 
+    async def get_important_messages(
+        self,
+        return_raw_response: bool = False,
+        count: typing.Optional[int] = None,
+        offset: typing.Optional[int] = None,
+        start_message_id: typing.Optional[int] = None,
+        preview_length: typing.Optional[int] = None,
+        fields: typing.Optional[typing.List[BaseUserGroupFields]] = None,
+        extended: typing.Optional[BaseBoolInt] = None,
+        group_id: typing.Optional[int] = None,
+    ) -> typing.Union[
+        dict,
+        MessagesGetImportantMessagesResponse,
+        MessagesGetImportantMessagesExtendedResponse,
+    ]:
+        """
+        :param count: - Amount of needed important messages.
+        :param offset:
+        :param start_message_id:
+        :param preview_length: - Maximum length of messages body.
+        :param fields: - Actors fields to return.
+        :param extended: - Return extended properties
+        :param group_id: - Group ID (for group messages with group access token)
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("getImportantMessages", params)
+        if return_raw_response:
+            return raw_result
+
+        result = (
+            MessagesGetImportantMessagesResponse(**raw_result)
+            if not extended
+            else MessagesGetImportantMessagesExtendedResponse(**raw_result)
+        )
+        return result
+
     async def get_invite_link(
         self,
         peer_id: int,
@@ -484,7 +550,9 @@ class Messages(Category):
         return result
 
     async def get_last_activity(
-        self, user_id: int, return_raw_response: bool = False,
+        self,
+        user_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, MessagesGetLastActivityResponse]:
         """
         :param user_id: - User ID.
@@ -506,7 +574,7 @@ class Messages(Category):
         return_raw_response: bool = False,
         ts: typing.Optional[int] = None,
         pts: typing.Optional[int] = None,
-        preview_length: typing.Optional[BaseBoolInt] = None,
+        preview_length: typing.Optional[int] = None,
         onlines: typing.Optional[BaseBoolInt] = None,
         fields: typing.Optional[typing.List[UsersFields]] = None,
         events_limit: typing.Optional[int] = None,
@@ -568,7 +636,10 @@ class Messages(Category):
         return result
 
     async def is_messages_from_group_allowed(
-        self, group_id: int, user_id: int, return_raw_response: bool = False,
+        self,
+        group_id: int,
+        user_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, MessagesIsMessagesFromGroupAllowedResponse]:
         """
         :param group_id: - Group ID.
@@ -587,7 +658,9 @@ class Messages(Category):
         return result
 
     async def join_chat_by_invite_link(
-        self, link: str, return_raw_response: bool = False,
+        self,
+        link: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, MessagesJoinChatByInviteLinkResponse]:
         """
         :param link: - Invitation link.
@@ -610,7 +683,7 @@ class Messages(Category):
         return_raw_response: bool = False,
         answered: typing.Optional[BaseBoolInt] = None,
         group_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param peer_id: - ID of conversation to mark as important.
         :param answered: - '1' — to mark as answered, '0' — to remove the mark
@@ -625,14 +698,14 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def mark_as_important(
         self,
         return_raw_response: bool = False,
         message_ids: typing.Optional[typing.List[int]] = None,
-        important: typing.Optional[BaseBoolInt] = None,
+        important: typing.Optional[int] = None,
     ) -> typing.Union[dict, MessagesMarkAsImportantResponse]:
         """
         :param message_ids: - IDs of messages to mark as important.
@@ -656,7 +729,7 @@ class Messages(Category):
         return_raw_response: bool = False,
         important: typing.Optional[BaseBoolInt] = None,
         group_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param peer_id: - ID of conversation to mark as important.
         :param important: - '1' — to add a star (mark as important), '0' — to remove the star
@@ -671,22 +744,24 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def mark_as_read(
         self,
         return_raw_response: bool = False,
         message_ids: typing.Optional[typing.List[int]] = None,
-        peer_id: typing.Optional[BaseBoolInt] = None,
+        peer_id: typing.Optional[int] = None,
         start_message_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        mark_conversation_as_read: typing.Optional[bool] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param message_ids: - IDs of messages to mark as read.
         :param peer_id: - Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
         :param start_message_id: - Message ID to start from.
         :param group_id: - Group ID (for group messages with user access token)
+        :param mark_conversation_as_read:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -697,18 +772,20 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def pin(
         self,
-        peer_id: BaseBoolInt,
+        peer_id: int,
         return_raw_response: bool = False,
         message_id: typing.Optional[int] = None,
+        conversation_message_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, MessagesPinResponse]:
         """
         :param peer_id: - Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
-        :param message_id:
+        :param message_id: - Message ID
+        :param conversation_message_id: - Conversation message ID
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -728,7 +805,7 @@ class Messages(Category):
         return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
         member_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param chat_id: - Chat ID.
         :param user_id: - ID of the user to be removed from the chat.
@@ -743,7 +820,7 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def restore(
@@ -751,7 +828,7 @@ class Messages(Category):
         message_id: int,
         return_raw_response: bool = False,
         group_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param message_id: - ID of a previously-deleted message to restore.
         :param group_id: - Group ID (for group messages with user access token)
@@ -765,16 +842,16 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def search(
         self,
         return_raw_response: bool = False,
         q: typing.Optional[str] = None,
-        peer_id: typing.Optional[BaseBoolInt] = None,
+        peer_id: typing.Optional[int] = None,
         date: typing.Optional[int] = None,
-        preview_length: typing.Optional[BaseBoolInt] = None,
+        preview_length: typing.Optional[int] = None,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         extended: typing.Optional[BaseBoolInt] = None,
@@ -837,29 +914,36 @@ class Messages(Category):
         return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
         random_id: typing.Optional[int] = None,
-        peer_id: typing.Optional[BaseBoolInt] = None,
+        peer_id: typing.Optional[int] = None,
+        peer_ids: typing.Optional[typing.List[int]] = None,
         domain: typing.Optional[str] = None,
         chat_id: typing.Optional[int] = None,
         user_ids: typing.Optional[typing.List[int]] = None,
         message: typing.Optional[str] = None,
-        lat: typing.Optional[BaseBoolInt] = None,
-        long: typing.Optional[BaseBoolInt] = None,
-        attachment: typing.Optional[BaseBoolInt] = None,
+        lat: typing.Optional[int] = None,
+        long: typing.Optional[int] = None,
+        attachment: typing.Optional[str] = None,
         reply_to: typing.Optional[int] = None,
         forward_messages: typing.Optional[typing.List[int]] = None,
         forward: typing.Optional[str] = None,
         sticker_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
         keyboard: typing.Optional[str] = None,
+        template: typing.Optional[str] = None,
         payload: typing.Optional[str] = None,
+        content_source: typing.Optional[str] = None,
         dont_parse_links: typing.Optional[bool] = None,
         disable_mentions: typing.Optional[bool] = None,
-        template: typing.Optional[str] = None,
-    ) -> typing.Union[dict, MessagesSendResponse]:
+        intent: typing.Optional[str] = None,
+        subscribe_id: typing.Optional[int] = None,
+        expire_ttl: typing.Optional[int] = None,
+        silent: typing.Optional[bool] = None,
+    ) -> typing.Union[dict, MessagesSendResponse, MessagesSendPeerIdsResponse]:
         """
         :param user_id: - User ID (by default — current user).
         :param random_id: - Unique identifier to avoid resending the message.
         :param peer_id: - Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
+        :param peer_ids: - IDs of message recipients. (See peer_id)
         :param domain: - User's short address (for example, 'illarionov').
         :param chat_id: - ID of conversation the message will relate to.
         :param user_ids: - IDs of message recipients (if new conversation shall be started).
@@ -869,14 +953,19 @@ class Messages(Category):
         :param attachment: - (Required if 'message' is not set.) List of objects attached to the message, separated by commas, in the following format: "<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, 'wall' — wall post, '<owner_id>' — ID of the media attachment owner. '<media_id>' — media attachment ID. Example: "photo100172_166443618"
         :param reply_to:
         :param forward_messages: - ID of forwarded messages, separated with a comma. Listed messages of the sender will be shown in the message body at the recipient's. Example: "123,431,544"
-        :param forward:
+        :param forward: - JSON describing the forwarded message or reply
         :param sticker_id: - Sticker id.
         :param group_id: - Group ID (for group messages with group access token)
         :param keyboard:
+        :param template:
         :param payload:
+        :param content_source: - JSON describing the content source in the message
         :param dont_parse_links:
         :param disable_mentions:
-        :param template:
+        :param intent:
+        :param subscribe_id:
+        :param expire_ttl: Message deletion timer. Accepts values: 15, 60, 300, 3600, 86400
+        :param silent: Silent notification. Accepts values: True, False
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -887,7 +976,36 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = MessagesSendResponse(**raw_result)
+        if user_ids or peer_ids:
+            result = MessagesSendPeerIdsResponse(**raw_result)
+        else:
+            result = MessagesSendResponse(**raw_result)
+        return result
+
+    async def send_message_event_answer(
+        self,
+        event_id: str,
+        user_id: int,
+        peer_id: int,
+        return_raw_response: bool = False,
+        event_data: typing.Optional[str] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
+        """
+        :param event_id:
+        :param user_id:
+        :param peer_id:
+        :param event_data:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("sendMessageEventAnswer", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def set_activity(
@@ -895,9 +1013,9 @@ class Messages(Category):
         return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
         type: typing.Optional[str] = None,
-        peer_id: typing.Optional[BaseBoolInt] = None,
+        peer_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param user_id: - User ID.
         :param type: - 'typing' — user has started to type.
@@ -913,11 +1031,13 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def set_chat_photo(
-        self, file: str, return_raw_response: bool = False,
+        self,
+        file: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, MessagesSetChatPhotoResponse]:
         """
         :param file: - Upload URL from the 'response' field returned by the [vk.com/dev/photos.getChatUploadServer|photos.getChatUploadServer] method upon successfully uploading an image.
@@ -939,7 +1059,7 @@ class Messages(Category):
         peer_id: int,
         return_raw_response: bool = False,
         group_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param peer_id:
         :param group_id:
@@ -953,5 +1073,28 @@ class Messages(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
+
+    async def set_conversation_style(
+        self,
+        peer_id: int,
+        style: typing.Optional[str] = None,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
+        """
+        this method is hidden and may be unstable!
+
+        :param peer_id:
+        :param style: - available values: candy, crimson, custom, default, disco, emerald, lagoon, marine, midnight, retrowave, sunset, twilight, unicorn
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("setConversationStyle", params)
+        if return_raw_response:
+            return raw_result
+
+        return BaseOkResponse(**raw_result)
