@@ -1,13 +1,14 @@
 from vkwave.types.responses import *
-
 from ._category import Category
 from ._utils import get_params
 
 
 class Stories(Category):
     async def ban_owner(
-        self, owners_ids: typing.List[int], return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        owners_ids: typing.List[int],
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owners_ids: - List of sources IDs
         :param return_raw_response: - return result at dict
@@ -20,15 +21,20 @@ class Stories(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def delete(
-        self, owner_id: int, story_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
+        story_id: typing.Optional[int] = None,
+        stories: typing.Optional[typing.List[str]] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - Story owner's ID. Current user id is used by default.
         :param story_id: - Story ID.
+        :param stories:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -39,7 +45,7 @@ class Stories(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def get(
@@ -47,10 +53,12 @@ class Stories(Category):
         return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
         extended: typing.Optional[BaseBoolInt] = None,
-    ) -> typing.Union[dict, StoriesGetResponse, StoriesGetExtendedResponse]:
+        fields: typing.Optional[typing.List[BaseUserGroupFields]] = None,
+    ) -> typing.Union[dict, StoriesGetV5113Response]:
         """
         :param owner_id: - Owner ID.
         :param extended: - '1' — to return additional fields for users and communities. Default value is 0.
+        :param fields:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -61,11 +69,7 @@ class Stories(Category):
         if return_raw_response:
             return raw_result
 
-        result = (
-            StoriesGetResponse(**raw_result)
-            if not extended
-            else StoriesGetExtendedResponse(**raw_result)
-        )
+        result = StoriesGetV5113Response(**raw_result)
         return result
 
     async def get_banned(
@@ -131,6 +135,7 @@ class Stories(Category):
         link_text: typing.Optional[str] = None,
         link_url: typing.Optional[str] = None,
         group_id: typing.Optional[int] = None,
+        clickable_stickers: typing.Optional[str] = None,
     ) -> typing.Union[dict, StoriesGetPhotoUploadServerResponse]:
         """
         :param add_to_news: - 1 — to add the story to friend's feed.
@@ -139,6 +144,7 @@ class Stories(Category):
         :param link_text: - Link text (for community's stories only).
         :param link_url: - Link URL. Internal links on https://vk.com only.
         :param group_id: - ID of the community to upload the story (should be verified or with the "fire" icon).
+        :param clickable_stickers:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -160,7 +166,7 @@ class Stories(Category):
         access_key: typing.Optional[str] = None,
         extended: typing.Optional[BaseBoolInt] = None,
         fields: typing.Optional[typing.List[BaseUserGroupFields]] = None,
-    ) -> typing.Union[dict, StoriesGetRepliesResponse, StoriesGetRepliesExtendedResponse]:
+    ) -> typing.Union[dict, StoriesGetV5113Response]:
         """
         :param owner_id: - Story owner ID.
         :param story_id: - Story ID.
@@ -177,18 +183,17 @@ class Stories(Category):
         if return_raw_response:
             return raw_result
 
-        result = (
-            StoriesGetRepliesResponse(**raw_result)
-            if not extended
-            else StoriesGetRepliesExtendedResponse(**raw_result)
-        )
+        result = StoriesGetV5113Response(**raw_result)
         return result
 
     async def get_stats(
-        self, owner_id: int, story_id: int, return_raw_response: bool = False,
+        self,
+        owner_id: int,
+        story_id: int,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, StoriesGetStatsResponse]:
         """
-        :param owner_id: - Story owner ID. 
+        :param owner_id: - Story owner ID.
         :param story_id: - Story ID.
         :param return_raw_response: - return result at dict
         :return:
@@ -212,6 +217,7 @@ class Stories(Category):
         link_text: typing.Optional[str] = None,
         link_url: typing.Optional[str] = None,
         group_id: typing.Optional[int] = None,
+        clickable_stickers: typing.Optional[str] = None,
     ) -> typing.Union[dict, StoriesGetVideoUploadServerResponse]:
         """
         :param add_to_news: - 1 — to add the story to friend's feed.
@@ -220,6 +226,7 @@ class Stories(Category):
         :param link_text: - Link text (for community's stories only).
         :param link_url: - Link URL. Internal links on https://vk.com only.
         :param group_id: - ID of the community to upload the story (should be verified or with the "fire" icon).
+        :param clickable_stickers:
         :param return_raw_response: - return result at dict
         :return:
         """
@@ -241,7 +248,11 @@ class Stories(Category):
         count: typing.Optional[int] = None,
         offset: typing.Optional[int] = None,
         extended: typing.Optional[BaseBoolInt] = None,
-    ) -> typing.Union[dict, StoriesGetViewersResponse, StoriesGetViewersExtendedResponse]:
+    ) -> typing.Union[
+        dict,
+        StoriesGetViewersExtendedV5115Response,
+        StoriesGetViewersExtendedV5115Response,
+    ]:
         """
         :param owner_id: - Story owner ID.
         :param story_id: - Story ID.
@@ -259,9 +270,9 @@ class Stories(Category):
             return raw_result
 
         result = (
-            StoriesGetViewersResponse(**raw_result)
+            StoriesGetViewersExtendedV5115Response(**raw_result)
             if not extended
-            else StoriesGetViewersExtendedResponse(**raw_result)
+            else StoriesGetViewersExtendedV5115Response(**raw_result)
         )
         return result
 
@@ -270,7 +281,7 @@ class Stories(Category):
         owner_id: int,
         return_raw_response: bool = False,
         group_id: typing.Optional[int] = None,
-    ) -> typing.Union[dict, OkResponse]:
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of the user whose replies should be hidden.
         :param group_id:
@@ -284,12 +295,15 @@ class Stories(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def hide_reply(
-        self, owner_id: int, story_id: int, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        owner_id: int,
+        story_id: int,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owner_id: - ID of the user whose replies should be hidden.
         :param story_id: - Story ID.
@@ -303,12 +317,98 @@ class Stories(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
+        return result
+
+    async def save(
+        self,
+        upload_results: typing.List[str],
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, StoriesSaveResponse]:
+        """
+        :param upload_results:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("save", params)
+        if return_raw_response:
+            return raw_result
+
+        result = StoriesSaveResponse(**raw_result)
+        return result
+
+    async def search(
+        self,
+        return_raw_response: bool = False,
+        q: typing.Optional[str] = None,
+        place_id: typing.Optional[int] = None,
+        latitude: typing.Optional[int] = None,
+        longitude: typing.Optional[int] = None,
+        radius: typing.Optional[int] = None,
+        mentioned_id: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+        extended: typing.Optional[BaseBoolInt] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+    ) -> typing.Union[dict, StoriesGetV5113Response]:
+        """
+        :param q:
+        :param place_id:
+        :param latitude:
+        :param longitude:
+        :param radius:
+        :param mentioned_id:
+        :param count:
+        :param extended:
+        :param fields:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("search", params)
+        if return_raw_response:
+            return raw_result
+
+        result = StoriesGetV5113Response(**raw_result)
+        return result
+
+    async def send_interaction(
+        self,
+        access_key: str,
+        return_raw_response: bool = False,
+        message: typing.Optional[str] = None,
+        is_broadcast: typing.Optional[bool] = None,
+        is_anonymous: typing.Optional[bool] = None,
+        unseen_marker: typing.Optional[bool] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
+        """
+        :param access_key:
+        :param message:
+        :param is_broadcast:
+        :param is_anonymous:
+        :param unseen_marker:
+        :param return_raw_response: - return result at dict
+        :return:
+        """
+
+        params = get_params(locals())
+
+        raw_result = await self.api_request("sendInteraction", params)
+        if return_raw_response:
+            return raw_result
+
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def unban_owner(
-        self, owners_ids: typing.List[int], return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        owners_ids: typing.List[int],
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param owners_ids: - List of hidden sources to show stories from.
         :param return_raw_response: - return result at dict
@@ -321,28 +421,5 @@ class Stories(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
-        return result
-
-    async def search(
-        self,
-        q: str,
-        place_id: typing.Optional[int] = None,
-        latitude: typing.Optional[int] = None,
-        longitude: typing.Optional[int] = None,
-        radius: typing.Optional[int] = None,
-        mentioned_id: typing.Optional[int] = None,
-        count: typing.Optional[int] = None,
-        extended: typing.Optional[BaseBoolInt] = None,
-        fields: typing.Optional[typing.List[BaseUserGroupFields]] = None,
-        return_raw_response: bool = False,
-    ) -> typing.Union[dict, StoriesSearchResponseModel]:
-
-        params = get_params(locals())
-
-        raw_result = await self.api_request("search", params)
-        if return_raw_response:
-            return raw_result
-
-        result = StoriesSearchResponseModel(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
