@@ -1,12 +1,12 @@
 from vkwave.types.responses import *
-
 from ._category import Category
 from ._utils import get_params
 
 
 class Streaming(Category):
     async def get_server_url(
-        self, return_raw_response: bool = False,
+        self,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, StreamingGetServerUrlResponse]:
         """
         :param return_raw_response: - return result at dict
@@ -23,8 +23,10 @@ class Streaming(Category):
         return result
 
     async def set_settings(
-        self, return_raw_response: bool = False, monthly_tier: typing.Optional[str] = None,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        return_raw_response: bool = False,
+        monthly_tier: typing.Optional[str] = None,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param monthly_tier:
         :param return_raw_response: - return result at dict
@@ -37,5 +39,5 @@ class Streaming(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
