@@ -1,12 +1,13 @@
 from vkwave.types.responses import *
-
 from ._category import Category
 from ._utils import get_params
 
 
 class Utils(Category):
     async def check_link(
-        self, url: str, return_raw_response: bool = False,
+        self,
+        url: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, UtilsCheckLinkResponse]:
         """
         :param url: - Link to check (e.g., 'http://google.com').
@@ -24,8 +25,10 @@ class Utils(Category):
         return result
 
     async def delete_from_last_shortened(
-        self, key: str, return_raw_response: bool = False,
-    ) -> typing.Union[dict, OkResponse]:
+        self,
+        key: str,
+        return_raw_response: bool = False,
+    ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param key: - Link key (characters after vk.cc/).
         :param return_raw_response: - return result at dict
@@ -38,7 +41,7 @@ class Utils(Category):
         if return_raw_response:
             return raw_result
 
-        result = OkResponse(**raw_result)
+        result = BaseOkResponse(**raw_result)
         return result
 
     async def get_last_shortened_links(
@@ -98,7 +101,8 @@ class Utils(Category):
         return result
 
     async def get_server_time(
-        self, return_raw_response: bool = False,
+        self,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, UtilsGetServerTimeResponse]:
         """
         :param return_raw_response: - return result at dict
@@ -137,7 +141,9 @@ class Utils(Category):
         return result
 
     async def resolve_screen_name(
-        self, screen_name: str, return_raw_response: bool = False,
+        self,
+        screen_name: str,
+        return_raw_response: bool = False,
     ) -> typing.Union[dict, UtilsResolveScreenNameResponse]:
         """
         :param screen_name: - Screen name of the user, community (e.g., 'apiclub,' 'andrew', or 'rules_of_war'), or application.
