@@ -12,9 +12,10 @@ from vkwave.bots.core.types.bot_type import BotType
 from vkwave.types.bot_events import get_event_object
 from vkwave.types.user_events import get_event_object as user_get_event_object
 
+from .result_caster import BaseResultCaster, ResultCaster
 from .middleware.middleware import MiddlewareManager
 from .processing_options import ProcessEventOptions
-from .result_caster import ResultCaster
+
 
 ProcessingResult = NewType("ProcessingResult", bool)
 
@@ -27,13 +28,14 @@ class Dispatcher:
         api: API,
         token_storage: Union[TokenStorage, UserTokenStorage],
         bot_type: BotType = BotType.BOT,
+        result_caster: Optional[BaseResultCaster] = None
     ):
         self.bot_type: BotType = bot_type
         self.api: API = api
         self.middleware_manager = MiddlewareManager()
         self.token_storage: Union[TokenStorage, UserTokenStorage] = token_storage
         self.routers: List[BaseRouter] = []
-        self.result_caster: ResultCaster = ResultCaster()
+        self.result_caster: BaseResultCaster = result_caster or ResultCaster()
 
     def add_router(self, router: BaseRouter):
         self.routers.append(router)
@@ -59,7 +61,7 @@ class Dispatcher:
         else:
             revent.raw_event = cast(list, revent.raw_event)
             obj = user_get_event_object(revent.raw_event)
-            event = UserEvent(obj, self.api.with_token(self.token_storage.current_token))
+            event = UserEvent(obj, self.api.with_token(await self.token_storage.get_token()))
 
         logger.debug(f"New event! Formatted:\n{event}")
 
@@ -71,9 +73,12 @@ class Dispatcher:
                 if result is HANDLER_NOT_FOUND:
                     continue
                 await self.result_caster.cast(result, event)
-                logger.debug("Event was succesfully handled")
+                logger.debug("Event was successfully handled")
+
+                await self.middleware_manager.execute_post_process_event(event)
                 return ProcessingResult(True)
         logger.debug("Event wasn't handled")
+        await self.middleware_manager.execute_post_process_event(event)
         return ProcessingResult(False)
 
     async def cache_potential_tokens(self, tokens: Optional[List[AnyABCToken]] = None):
