@@ -11,6 +11,9 @@ class BaseMiddleware(ABC):
     async def pre_process_event(self, event: BaseEvent) -> MiddlewareResult:
         ...
 
+    async def post_process_event(self, event: BaseEvent):
+        pass
+
 
 class MiddlewareManager:
     def __init__(self):
@@ -25,3 +28,7 @@ class MiddlewareManager:
             if not m_res:
                 return MiddlewareResult(False)
         return MiddlewareResult(True)
+
+    async def execute_post_process_event(self, event: BaseEvent):
+        for middleware in self.middlewares:
+            await middleware.post_process_event(event)
