@@ -11,27 +11,30 @@ except ImportError:
 
 
 class VBMLFilter(BaseFilter):
-    def __init__(self, pattern: typing.Union["vbml.Pattern", str], patcher: typing.Optional["vbml.Patcher"] = None):
+    def __init__(
+        self,
+        pattern: typing.Union["vbml.Pattern", str],
+        patcher: typing.Optional["vbml.Patcher"] = None,
+        ignore_case: bool = False,
+    ):
         if vbml is None:
             raise RuntimeError("you have to install vbml - pip install vbml")
 
-        if patcher is None:
-            self.patcher = vbml.Patcher()
+        self.patcher: vbml.Patcher = patcher or vbml.Patcher()
 
         if isinstance(pattern, str):
-            self.pattern = vbml.Patcher.get_current(no_error=False).pattern(pattern)
+            self.pattern = vbml.Pattern(pattern)
         elif isinstance(pattern, vbml.Pattern):
             self.pattern = pattern
-
-        self._patcher = vbml.Patcher.get_current(no_error=False)
+        self.ignore_case = ignore_case
 
     async def check(self, event: BaseEvent) -> FilterResult:
-        text = get_text(event)
+        text = get_text(event) if not self.ignore_case else get_text(event).lower()
         if text is None:
             return FilterResult(False)
 
-        result = self._patcher.check(text, self.pattern)
-        if result is None:
+        result = self.patcher.check(self.pattern, text)
+        if not result:
             return FilterResult(False)
 
         event["vmbl_data"] = self.pattern.dict()
