@@ -1,11 +1,12 @@
 import typing
 from enum import Enum, auto
 
+from vkwave.bots import BotType
 from vkwave.bots.core.dispatching.events.base import BaseEvent
 from vkwave.bots.fsm.types import StateId
 from vkwave.bots.storage.base import AbstractStorage
 from vkwave.bots.storage.storages import Storage
-from vkwave.bots.storage.types import Key
+from vkwave.bots.storage.types import Key, Value
 
 
 class ForWhat(Enum):
@@ -14,12 +15,27 @@ class ForWhat(Enum):
     FOR_USER_IN_CHAT = auto()  # default
 
 
+def get_peer_from_ids(event: BaseEvent) -> typing.Tuple[int, int]:
+    if event.bot_type is BotType.BOT:
+        if event.object.object.dict().get("message") is not None:
+            from_id = event.object.object.message.from_id
+            peer_id = event.object.object.message.peer_id
+        else:
+            # CallbackButtonEventObject
+            from_id = event.object.object.user_id
+            peer_id = event.object.object.peer_id
+    else:
+        peer_id = from_id = event.object.object.peer_id
+        if peer_id > 2e9:
+            from_id = int(event.object.object.message_data.from_id)
+    return from_id, peer_id
+
+
 def create_state_id(event: BaseEvent, for_what: ForWhat = ForWhat.FOR_USER_IN_CHAT) -> StateId:
     res: str
 
     template = "__vkwave_{for_what}_{peer_id}_{from_id}__"
-    from_id = event.object.object.message.from_id
-    peer_id = event.object.object.message.peer_id
+    from_id, peer_id = get_peer_from_ids(event)
 
     is_pm = from_id == peer_id
     is_chat = not is_pm
@@ -78,7 +94,7 @@ class FiniteStateMachine:
         data.update(state_data)
         return await self.storage.put(sid, data)
 
-    async def get_data(self, event: BaseEvent, for_what: ForWhat) -> None:
+    async def get_data(self, event: BaseEvent, for_what: ForWhat) -> typing.Optional[Value]:
         sid = Key(create_state_id(event, for_what))
         return await self.storage.get(sid, default=None)
 
