@@ -1,3 +1,3 @@
 from .doc_uploader import DocUploader, GraffitiUploader, VoiceUploader  # noqa: F401
-from .photo_uploader import PhotoUploader  # noqa: F401
+from .photo_uploader import PhotoUploader, WallPhotoUploader  # noqa: F401
 from .uploader import BaseUploader  # noqa: F401
