@@ -12,6 +12,8 @@ from .objects import (
     VideoVideo,
     WallWallComment,
     WallWallpost,
+    LikesType,
+    MarketOrder,
 )
 
 
@@ -47,6 +49,8 @@ class BotEventType(str, Enum):
     MARKET_COMMENT_EDIT = "market_comment_edit"
     MARKET_COMMENT_RESTORE = "market_comment_restore"
     MARKET_COMMENT_DELETE = "market_comment_delete"
+    MARKET_ORDER_NEW = "market_order_new"  # Needs extended market in group
+    MARKET_ORDER_EDIT = "market_order_edit"  # Needs extended market in group
     GROUP_LEAVE = "group_leave"
     GROUP_JOIN = "group_join"
     USER_BLOCK = "user_block"
@@ -58,6 +62,9 @@ class BotEventType(str, Enum):
     VKPAY_TRANSACTION = "vkpay_transaction"
     APP_PAYLOAD = "app_payload"
     CALLBACK_CONFIRMATION = "confirmation"
+    MESSAGE_EVENT = "message_event"
+    LIKE_ADD = "like_add"
+    LIKE_REMOVE = "like_remove"
 
 
 class BaseBotEvent(pydantic.BaseModel):
@@ -94,6 +101,8 @@ class BaseBotEvent(pydantic.BaseModel):
         "MarketCommentObject",
         "MarketCommentObject",
         "MarketCommentDeleteObject",
+        "MarketOrderNew",
+        "MarketOrderEdit",
         "GroupLeaveObject",
         "GroupJoinObject",
         "UserBlockObject",
@@ -106,6 +115,9 @@ class BaseBotEvent(pydantic.BaseModel):
         "AppPayloadObject",
         "MessageTypingStateObject",
         "BaseBotEvent",
+        "CallbackButtonEventObject",
+        "LikeAdd",
+        "LikeRemove",
     ]
     event_id: typing.Optional[str]
 
@@ -254,8 +266,7 @@ class WallRepost(BaseBotEvent):
     object: WallPostObject = pydantic.Field(None, description="")
 
 
-class WallReplyObject(pydantic.BaseModel):
-    comment: WallWallComment = pydantic.Field(None, description="")
+class WallReplyObject(WallWallComment):
     post_id: int = pydantic.Field(None, description="")
     post_owner_id: int = pydantic.Field(None, description="")
 
@@ -341,6 +352,14 @@ class MarketCommentDelete(BaseBotEvent):
     object: MarketCommentDeleteObject = pydantic.Field(None, description="")
 
 
+class MarketOrderNew(BaseBotEvent):
+    object: MarketOrder = pydantic.Field(None, description="")
+
+
+class MarketOrderEdit(BaseBotEvent):
+    object: MarketOrder = pydantic.Field(None, description="")
+
+
 class GroupLeaveEnum(int, Enum):
     NOT_SELF_LEAVED = 0
     SELF_LEAVED = 1
@@ -477,6 +496,44 @@ class CallBackConfirmation(BaseBotEvent):
     pass
 
 
+class CallbackButtonEventObject(pydantic.BaseModel):
+    conversation_message_id: int = pydantic.Field(None, description="")
+    user_id: int = pydantic.Field(None, description="")
+    peer_id: int = pydantic.Field(None, description="")
+    payload: typing.Dict[str, str] = pydantic.Field(None, description="")
+    event_id: str = pydantic.Field(None, description="")
+
+
+class CallbackButtonEvent(BaseBotEvent):
+    object: CallbackButtonEventObject = pydantic.Field(None, description="")
+
+
+class LikeAddEventObject(pydantic.BaseModel):
+    liker_id: int = pydantic.Field(None, description="")
+    object_type: LikesType = pydantic.Field(None, description="")
+    object_owner_id: int = pydantic.Field(None, description="")
+    object_id: int = pydantic.Field(None, description="")
+    thread_reply_id: int = pydantic.Field(None, description="")
+    post_id: int = pydantic.Field(None, description="")
+
+
+class LikeAdd(BaseBotEvent):
+    object: LikeAddEventObject = pydantic.Field(None, description="")
+
+
+class LikeRemoveEventObject(pydantic.BaseModel):
+    liker_id: int = pydantic.Field(None, description="")
+    object_type: LikesType = pydantic.Field(None, description="")
+    object_owner_id: int = pydantic.Field(None, description="")
+    object_id: int = pydantic.Field(None, description="")
+    thread_reply_id: int = pydantic.Field(None, description="")
+    post_id: int = pydantic.Field(None, description="")
+
+
+class LikeRemove(BaseBotEvent):
+    object: LikeRemoveEventObject = pydantic.Field(None, description="")
+
+
 _event_dict = {
     "message_new": MessageNew,
     "message_reply": MessageReply,
@@ -508,6 +565,8 @@ _event_dict = {
     "market_comment_edit": MarketCommentEdit,
     "market_comment_restore": MarketCommentRestore,
     "market_comment_delete": MarketCommentDelete,
+    "market_order_new": MarketOrderNew,
+    "market_order_edit": MarketOrderEdit,
     "group_leave": GroupLeave,
     "group_join": GroupJoin,
     "user_block": UserBlock,
@@ -520,6 +579,9 @@ _event_dict = {
     "app_payload": AppPayload,
     "confirmation": CallBackConfirmation,
     "message_typing_state": MessageTypingState,
+    "message_event": CallbackButtonEvent,
+    "like_add": LikeAdd,
+    "like_remove": LikeRemove,
 }
 
 
@@ -556,6 +618,8 @@ def get_event_object(
     MarketCommentEdit,
     MarketCommentRestore,
     MarketCommentDelete,
+    MarketOrderNew,
+    MarketOrderEdit,
     GroupLeave,
     GroupJoin,
     UserBlock,
@@ -569,6 +633,9 @@ def get_event_object(
     CallBackConfirmation,
     MessageTypingState,
     BaseBotEvent,
+    CallbackButtonEvent,
+    LikeRemove,
+    LikeAdd,
 ]:
     event_type: str = raw_event["type"]
     event_model: typing.Type[BaseBotEvent] = _event_dict[event_type]
